<?php
// Helper functions
require( get_template_directory() . '/includes/helper-functions.php' );

// Option tree theme options
define( 'OT_THEME_VERSION', '2.6.1' );

// Filters the Theme Options ID - modded to work with Polylang
function uni_asana_theme_options_id() {

	$sDefault = 'option_tree';

	if ( function_exists( 'pll_home_url' ) ) {
		if ( is_admin() || is_customize_preview() ) {
			$user_lang     = get_user_meta( get_current_user_id(), 'pll_filter_content', true );
			$selected_lang = filter_input( INPUT_GET, 'lang', FILTER_SANITIZE_STRING );
			$lang          = $selected_lang !== null ? $selected_lang : $user_lang;
		} else {
			$lang = pll_current_language();
		}

		if ( $lang AND $lang != 'all' AND $lang != pll_default_language() ) {
			return $sDefault . '_' . $lang;
		}
	}

	return $sDefault;
}

add_filter( 'ot_options_id', 'uni_asana_theme_options_id' );

// Filters the Theme Option header list.
function filter_demo_header_list() {
	echo '<li id="theme-version"><span>Asana WP Theme 1.7.6</span></li>';
}

add_action( 'ot_header_list', 'filter_demo_header_list' );

//add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_theme_mode', '__return_true' );
add_filter( 'ot_show_options_ui', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );
add_filter( 'ot_show_docs', '__return_false' );
add_filter( 'ot_use_theme_options', '__return_true' );
require( get_template_directory() . '/includes/theme-options.php' );
require( get_template_directory() . '/option-tree/ot-loader.php' );
require( get_template_directory() . '/includes/uni-metabox.php' );

// Customizer additions.
require( get_template_directory() . '/includes/customizer.php' );

// $content_width
if ( ! isset( $content_width ) ) {
	$content_width = 1170;
}

// after setup of the child theme
add_action( 'after_setup_theme', 'uni_asana_theme_setup' );
function uni_asana_theme_setup() {

	// Enable featured image
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// Add html5 suppost for search form and comments list
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

	// translation files for the child theme
	load_theme_textdomain( 'asana', get_stylesheet_directory() . '/languages' );

	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	add_theme_support( 'uni-custom-logo-a', array(
		'height'      => ( ( ot_get_option( 'uni_logo_height' ) ) ? ot_get_option( 'uni_logo_height' ) : 32 ),
		'width'       => ( ( ot_get_option( 'uni_logo_width' ) ) ? ot_get_option( 'uni_logo_width' ) : 122 ),
		'flex-height' => false,
		'flex-width'  => false,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	add_theme_support( 'uni-custom-logo-b', array(
		'height'      => ( ( ot_get_option( 'uni_logo_height' ) ) ? ot_get_option( 'uni_logo_height' ) : 32 ),
		'width'       => ( ( ot_get_option( 'uni_logo_width' ) ) ? ot_get_option( 'uni_logo_width' ) : 122 ),
		'flex-height' => false,
		'flex-width'  => false,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );
}

// Colour schemes
add_filter( 'ot_radio_images', 'uni_asana_theme_color_schemes_radio_images', 10, 2 );
function uni_asana_theme_color_schemes_radio_images( $array, $field_id ) {
	if ( $field_id == 'uni_color_schemes' ) {
		$array = array(
			array(
				'value' => 'default',
				'label' => esc_html__( 'Default scheme', 'asana' ),
				'src'   => get_template_directory_uri() . '/images/schemes/default.jpg'
			),
			array(
				'value' => 'purple',
				'label' => esc_html__( 'Purple colour scheme', 'asana' ),
				'src'   => get_template_directory_uri() . '/images/schemes/purple.jpg'
			),
			array(
				'value' => 'blue',
				'label' => esc_html__( 'Blue colour scheme', 'asana' ),
				'src'   => get_template_directory_uri() . '/images/schemes/blue.jpg'
			),
			array(
				'value' => 'red',
				'label' => esc_html__( 'Red colour scheme', 'asana' ),
				'src'   => get_template_directory_uri() . '/images/schemes/red.jpg'
			),
			array(
				'value' => 'orange',
				'label' => esc_html__( 'Orange colour scheme', 'asana' ),
				'src'   => get_template_directory_uri() . '/images/schemes/orange.jpg'
			),
		);
	}

	return $array;
}

// map styles
function uni_asana_theme_map_styles() {

	$aArray = array(
		array(
			'value' => 'asanaShadesOfGrey',
			'label' => 'Shades of Grey',
			'src'   => ''
		),
		array(
			'value' => 'asanaCartoon',
			'label' => 'Cartoon',
			'src'   => ''
		),
		array(
			'value' => 'asanaGrey',
			'label' => 'Grey Scale (dafault)',
			'src'   => ''
		),
		array(
			'value' => 'asanaBlackWhite',
			'label' => 'Black & White',
			'src'   => ''
		),
		array(
			'value' => 'asanaRetro',
			'label' => 'Retro',
			'src'   => ''
		),
		array(
			'value' => 'asanaNight',
			'label' => 'Night',
			'src'   => ''
		),
		array(
			'value' => 'asanaNightLight',
			'label' => 'Night Light',
			'src'   => ''
		),
		array(
			'value' => 'asanaPapiro',
			'label' => 'Papiro',
			'src'   => ''
		),
		array(
			'value' => 'asanaDefaultGoogleMap',
			'label' => 'Google Map Standrard',
			'src'   => ''
		)
	);

	return $aArray;
}

// Mailchimp API 3.0
include( get_template_directory() . '/includes/class-uni-mailchimp-universal.php' );

// Register Custom Menu Function
if ( function_exists( 'register_nav_menus' ) ) {
	register_nav_menus( array(
		'primary' => esc_html__( 'Asana Main Menu', 'asana' ),
		'footer'  => esc_html__( 'Asana Footer Menu', 'asana' )
	) );
}

// Menu fallback
function uni_asana_theme_nav_fallback() {
	$sOutput = '<nav class="mainMenu"><ul class="clear">';
	$sOutput .= wp_list_pages( array( 'title_li' => '', 'echo' => false ) );
	$sOutput .= '</ul></nav>';
	echo $sOutput;
}

// Menu footer fallback
function uni_asana_theme_nav_footer_fallback() {
	$sOutput = '';
	echo $sOutput;
}

// add wp site icon fallback
add_filter( 'wp_head', 'uni_asana_theme_site_icon_fallback', 17 );
function uni_asana_theme_site_icon_fallback() {
	if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {
		echo '<link rel="shortcut icon" href="' . esc_url( get_stylesheet_directory_uri() ) . '/favicon.ico" type="image/x-icon" />';
		echo '<link rel="apple-touch-icon-precomposed" sizes="144x144" href="' . esc_url( get_stylesheet_directory_uri() ) . '/apple-touch-icon-144x144.png" />';
		echo '<link rel="apple-touch-icon-precomposed" sizes="152x152" href="' . esc_url( get_stylesheet_directory_uri() ) . '/apple-touch-icon-152x152.png" />';
		echo '<link rel="icon" type="image/png" href="' . esc_url( get_stylesheet_directory_uri() ) . '/favicon-32x32.png" sizes="32x32" />';
		echo '<link rel="icon" type="image/png" href="' . esc_url( get_stylesheet_directory_uri() ) . '/favicon-16x16.png" sizes="16x16" />';
	}
}

// wp-title
add_theme_support( 'title-tag' );
if ( ! function_exists( '_wp_render_title_tag' ) ) :
	function uni_asana_theme_render_title() {
		?>
        <title><?php wp_title( '-', true, 'right' ); ?></title>
		<?php
	}

	add_action( 'wp_head', 'uni_asana_theme_render_title' );
endif;

// TGM class 2.5.0 - neccessary plugins
include( get_template_directory() . '/includes/class-tgm-plugin-activation.php' );

add_action( 'tgmpa_register', 'uni_asana_theme_register_required_plugins' );
function uni_asana_theme_register_required_plugins() {

	$plugins = array(
		array(
			'name'     => 'Instagram Feed',
			'slug'     => 'instagram-feed',
			'required' => true,
		),
		array(
			'name'               => 'Envato Market',
			'slug'               => 'envato-market',
			'source'             => get_template_directory() . '/includes/plugins/envato-market.zip',
			'required'           => false,
			'version'            => '1.0.0-RC2',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => 'http://envato.github.io/wp-envato-market/'
		),
		array(
			'name'               => 'Uni Custom Post Types and Taxonomies',
			'slug'               => 'uni-cpt-and-tax',
			'source'             => get_template_directory() . '/includes/plugins/uni-cpt-and-tax.zip',
			'required'           => true,
			'version'            => '1.3.2',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
		),
		array(
			'name'               => 'Calendarius',
			'slug'               => 'uni-calendarius',
			'source'             => get_template_directory() . '/includes/plugins/uni-calendarius.zip',
			'required'           => true,
			'version'            => '1.2.4',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => 'https://codecanyon.net/item/calendarius-comprehensive-modern-calendar-plugin-for-wordpress/19107505',
		),
		array(
			'name'               => 'Profilini - Avatar and Profile Manager',
			'slug'               => 'uni-profilini',
			'source'             => get_template_directory() . '/includes/plugins/uni-profilini.zip',
			'required'           => false,
			'version'            => '2.0.0-beta',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
		),
		array(
			'name'               => 'Revolution Slider',
			'slug'               => 'revslider',
			'source'             => get_template_directory() . '/includes/plugins/revslider.zip',
			'required'           => true,
			'version'            => '5.4.3',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => 'http://themeforest.net/item/slider-revolution-responsive-wordpress-plugin/2751380',
		),
		array(
			'name'               => 'Uni Sortable Users',
			'slug'               => 'uni-sortable-users',
			'source'             => get_template_directory() . '/includes/plugins/uni-sortable-users.zip',
			'required'           => false,
			'version'            => '1.0.0',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
		),
		array(
			'name'     => 'WooCommerce - excelling eCommerce',
			'slug'     => 'woocommerce',
			'required' => false,
		),
		array(
			'name'     => 'Ecwid Shopping Cart',
			'slug'     => 'ecwid-shopping-cart',
			'required' => false,
		),
		array(
			'name'     => 'Contact Form 7',
			'slug'     => 'contact-form-7',
			'required' => false,
		),
		array(
			'name'     => 'Intuitive Custom Post Order',
			'slug'     => 'intuitive-custom-post-order',
			'required' => false,
		),
		array(
			'name'     => 'Shortcodes Ultimate',
			'slug'     => 'shortcodes-ultimate',
			'required' => false,
		),
		array(
			'name'     => 'WordPress Event Ticketing',
			'slug'     => 'tickera-event-ticketing-system',
			'required' => false,
		),
		array(
			'name'               => 'Uni CPO - WooCommerce Options and Price Calculation Formulas',
			'slug'               => 'uni-woo-custom-product-options',
			'source'             => '',
			'required'           => false,
			'version'            => '3.1.4',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => 'http://codecanyon.net/item/uni-cpo-price-calculation-formulas-for-woocommerce/9333768',
		),
		array(
			'name'               => 'WooCommerce Subscriptions',
			'slug'               => 'woocommerce-subscriptions',
			'source'             => '',
			'required'           => false,
			'version'            => '2.0.12',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => 'https://www.woothemes.com/products/woocommerce-subscriptions/',
		)
	);

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'default_path' => '',
		// Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins',
		// Menu slug.
		'has_notices'  => true,
		// Show admin notices or not.
		'dismissable'  => true,
		// If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',
		// If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,
		// Automatically activate plugins after installation or not.
		'message'      => '<div id="setting-error-tgmpa" class="updated settings-error notice is-dismissible"><p>' . esc_html__( 'Important: "WooCommerce Subscriptions" and "Uni CPO - WooCommerce Options and Price Calculation Formulas" are NOT bundled with the theme and CANNOT be installed and activated if you have not bought and uploaded them additionally!', 'asana' ) . '</p></div>',
		'strings'      => array(
			'page_title'                      => __( 'Install Required Plugins', 'asana' ),
			'menu_title'                      => __( 'Install Plugins', 'asana' ),
			'installing'                      => __( 'Installing Plugin: %s', 'asana' ),
			// %s = plugin name.
			'oops'                            => __( 'Something went wrong with the plugin API.', 'asana' ),
			'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'asana' ),
			// %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'asana' ),
			// %1$s = plugin name(s).
			'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'asana' ),
			'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'asana' ),
			'return'                          => __( 'Return to Required Plugins Installer', 'asana' ),
			'plugin_activated'                => __( 'Plugin activated successfully.', 'asana' ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', 'asana' ),
			// %s = dashboard link.
			'nag_type'                        => 'updated'
			// Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);

	tgmpa( $plugins, $config );

}

// Load necessary theme scripts and styles
function uni_asana_theme_scripts() {

	$sLocale   = get_locale();
	$aLocale   = explode( '_', $sLocale );
	$sLangCode = $aLocale[0];

	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
	// bxSlider
	wp_enqueue_script( 'jquery-bxslider-min', get_template_directory_uri() . '/js/jquery.bxslider.min.js', array( 'jquery' ), '4.2.3' );
	// jscrollpane
	wp_enqueue_script( 'jquery-jscrollpane-min', get_template_directory_uri() . '/js/jquery.jscrollpane.min.js', array( 'jquery' ), '4.2.3' );
	// mousewheel
	wp_enqueue_script( 'jquery-mousewheel', get_template_directory_uri() . '/js/jquery.mousewheel.js', array( 'jquery' ), '4.2.3' );
	// dotdotdot
	wp_enqueue_script( 'jquery-dotdotdot-min', get_template_directory_uri() . '/js/jquery.dotdotdot.min.js', array( 'jquery' ), '4.2.3' );
	// jquery.selectric.min
	wp_enqueue_script( 'jquery-selectric-min', get_template_directory_uri() . '/js/jquery.selectric.min.js', array( 'jquery' ), '1.8.7' );
	// jquery.infinitescroll
	wp_enqueue_script( 'jquery-infinitescroll-min', get_template_directory_uri() . '/js/jquery.infinitescroll.min.js', array( 'jquery' ), '2.1.0' );
	// jquery.fancybox.pack
	wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri() . '/js/jquery.fancybox.pack.js', array( 'jquery' ), '2.1.5' );
	// jquery.blockUI
	wp_enqueue_script( 'jquery-blockui', get_template_directory_uri() . '/js/jquery.blockUI.js', array( 'jquery' ), '2.70.0' );
	// parsley
	wp_enqueue_script( 'jquery-parsley-min', get_template_directory_uri() . '/js/parsley.min.js', array( 'jquery' ), '2.7.0' );
	// parsley localization
	wp_enqueue_script( 'parsley-localization', get_template_directory_uri() . '/js/parsley/i18n/en.js', array( 'jquery-parsley-min' ), '2.7.0' );
	// Asana scripts
	wp_register_script( 'uni-asana-theme-script', get_template_directory_uri() . '/js/script.js', array(
		'jquery',
		'jquery-bxslider-min',
		'jquery-jscrollpane-min',
		'jquery-mousewheel',
		'jquery-dotdotdot-min',
		'jquery-selectric-min',
		'jquery-infinitescroll-min',
		'jquery-fancybox',
		'jquery-blockui',
		'jquery-parsley-min'
	), '1.7.6' );
	wp_enqueue_script( 'uni-asana-theme-script' );

	$sPageHeaderImage = '';
	$iShopAttachId    = ( ot_get_option( 'uni_shop_header_bg' ) ) ? ot_get_option( 'uni_shop_header_bg' ) : '';
	if ( ! empty( $iShopAttachId ) ) {
		$aPageHeaderImage = wp_get_attachment_image_src( $iShopAttachId, 'full' );
		$sPageHeaderImage = $aPageHeaderImage[0];
	} else {
		$sPageHeaderImage = get_template_directory_uri() . '/images/placeholders/pageheader-shop.jpg';
	}

	$params = array(
		'site_url'              => home_url(),
		'ajax_url'              => admin_url( 'admin-ajax.php' ),
		'is_home'               => 'no',
		'locale'                => $sLangCode,
		'white_nav'             => ( ( ot_get_option( 'uni_nav_white_enable' ) && ot_get_option( 'uni_nav_white_enable' ) == 'on' ) ? true : false ),
		'lazy_load_on_products' => ( ( ot_get_option( 'uni_ajax_scroll_enable_products' ) == 'on' ) ? true : false ),
		'lazy_load_on_posts'    => ( ( ot_get_option( 'uni_ajax_scroll_enable_posts' ) == 'on' ) ? true : false ),
		'lazy_load_on_events'   => ( ( ot_get_option( 'uni_ajax_scroll_enable_events' ) == 'on' ) ? true : false ),
		'lazy_load_end'         => esc_html__( 'You have reached the end', 'asana' ),
		'lazy_loader'           => get_template_directory_uri() . '/images/lazy_loader.png',
		'shop_text'             => ( ( ot_get_option( 'uni_shop_header_title' ) ) ? esc_html( ot_get_option( 'uni_shop_header_title' ) ) : esc_html__( 'ONLINE BOUTIQUE', 'asana' ) ),
		'shop_text_color'       => ( ot_get_option( 'uni_shop_header_title_color' ) ) ? ot_get_option( 'uni_shop_header_title_color' ) : '#ffffff',
		'shop_image'            => $sPageHeaderImage,
		'error_msg'             => esc_html__( 'Error!', 'asana' )
	);


	if ( is_home() ) {
		$params['is_home'] = 'yes';
	}

	wp_localize_script( 'uni-asana-theme-script', 'uni_asana_theme_var', $params );

	// parsley localization
	$aParsleyStrings = apply_filters( 'uni_asana_theme_parsley_strings_filter', array(
			'defaultMessage' => __( "This value seems to be invalid.", 'asana' ),
			'type_email'     => __( "This value should be a valid email.", 'asana' ),
			'type_url'       => __( "This value should be a valid url.", 'asana' ),
			'type_number'    => __( "This value should be a valid number.", 'asana' ),
			'type_digits'    => __( "This value should be digits.", 'asana' ),
			'type_alphanum'  => __( "This value should be alphanumeric.", 'asana' ),
			'type_integer'   => __( "This value should be a valid integer.", 'asana' ),
			'notblank'       => __( "This value should not be blank.", 'asana' ),
			'required'       => __( "This value is required.", 'asana' ),
			'pattern'        => __( "This value seems to be invalid.", 'asana' ),
			'min'            => __( "This value should be greater than or equal to %s.", 'asana' ),
			'max'            => __( "This value should be lower than or equal to %s.", 'asana' ),
			'range'          => __( "This value should be between %s and %s.", 'asana' ),
			'minlength'      => __( "This value is too short. It should have %s characters or more.", 'asana' ),
			'maxlength'      => __( "This value is too long. It should have %s characters or fewer.", 'asana' ),
			'length'         => __( "This value length is invalid. It should be between %s and %s characters long.", 'asana' ),
			'mincheck'       => __( "You must select at least %s choices.", 'asana' ),
			'maxcheck'       => __( "You must select %s choices or fewer.", 'asana' ),
			'check'          => __( "You must select between %s and %s choices.", 'asana' ),
			'equalto'        => __( "This value should be the same.", 'asana' ),
			'dateiso'        => __( "This value should be a valid date (YYYY-MM-DD).", 'asana' ),
			'minwords'       => __( "This value is too short. It should have %s words or more.", 'asana' ),
			'maxwords'       => __( "This value is too long. It should have %s words or fewer.", 'asana' ),
			'words'          => __( "This value length is invalid. It should be between %s and %s words long.", 'asana' ),
			'gt'             => __( "This value should be greater.", 'asana' ),
			'gte'            => __( "This value should be greater or equal.", 'asana' ),
			'lt'             => __( "This value should be less.", 'asana' ),
			'lte'            => __( "This value should be less or equal.", 'asana' ),
			'notequalto'     => __( "This value should be different.", 'asana' )
		)
	);

	wp_localize_script( 'jquery-parsley-min', 'uni_asana_theme_parsley_loc', $aParsleyStrings );

}

add_action( 'wp_enqueue_scripts', 'uni_asana_theme_scripts' );

// add google maps js api 3 script
function uni_asana_theme_enqueue_google_maps_script() {

	$sApiKey = ot_get_option( 'uni_gmaps_api_key' );
	if ( ot_get_option( 'uni_gmaps_elsewhere_enable' ) != 'on'
	     && (
		     is_page_template( 'templ-contact.php' ) || is_singular( 'uni_event' ) || is_singular( 'tc_events' )
	     ) ) {
		if ( ! empty( $sApiKey ) ) {
			wp_enqueue_script( 'google-maps', '//maps.googleapis.com/maps/api/js?key=' . esc_attr( $sApiKey ) );
		} else {
			wp_enqueue_script( 'google-maps', '//maps.googleapis.com/maps/api/js', array(), '' );
		}
	} else if ( ot_get_option( 'uni_gmaps_elsewhere_enable' ) == 'on' ) {
		if ( ! empty( $sApiKey ) ) {
			wp_enqueue_script( 'google-maps', '//maps.googleapis.com/maps/api/js?key=' . esc_attr( $sApiKey ) );
		} else {
			wp_enqueue_script( 'google-maps', '//maps.googleapis.com/maps/api/js', array(), '' );
		}
	}

}

add_action( 'wp_enqueue_scripts', 'uni_asana_theme_enqueue_google_maps_script' );

// Enqueue style.css (default WordPress stylesheet)
function uni_asana_theme_styles() {

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.7.0' );

	$ot_set_google_fonts = get_theme_mod( 'ot_set_google_fonts', array() );

	if ( ! ot_get_option( 'uni_google_fonts' ) || empty( $ot_set_google_fonts ) ) {
		wp_enqueue_style( 'uni-asana-theme-fonts', uni_asana_theme_fonts_url(), array(), '1.7.6' );
	}

	wp_register_style( 'bxslider-styles', get_template_directory_uri() . '/css/bxslider.css', '4.2.3' );
	wp_enqueue_style( 'bxslider-styles' );

	wp_register_style( 'ball-clip-rotate-styles', get_template_directory_uri() . '/css/ball-clip-rotate.css', '0.1.0' );
	wp_enqueue_style( 'ball-clip-rotate-styles' );

	wp_register_style( 'fancybox-styles', get_template_directory_uri() . '/css/fancybox.css', '2.1.5' );
	wp_enqueue_style( 'fancybox-styles' );

	wp_register_style( 'jscrollpane-styles', get_template_directory_uri() . '/css/jscrollpane.css', '2.1.5' );
	wp_enqueue_style( 'jscrollpane-styles' );

	wp_register_style( 'selectric-styles', get_template_directory_uri() . '/css/selectric.css', '2.1.5' );
	wp_enqueue_style( 'selectric-styles' );

	wp_register_style( 'unitheme-styles', get_template_directory_uri() . '/style.css', array(
		'bxslider-styles',
		'ball-clip-rotate-styles',
		'fancybox-styles',
		'jscrollpane-styles',
		'selectric-styles'
	), '1.7.6', 'all' );
	wp_enqueue_style( 'unitheme-styles' );

	if ( class_exists( 'WooCommerce' ) ) {
		wp_register_style( 'asana-woocommerce-styles', get_template_directory_uri() . '/css/woocommerce-store.css', '1.7.6' );
		wp_enqueue_style( 'asana-woocommerce-styles' );
	}

	if ( function_exists( 'ecwid_check_version' ) ) {
		wp_register_style( 'asana-ecwid-styles', get_template_directory_uri() . '/css/ecwid-store.css', '1.7.6' );
		wp_enqueue_style( 'asana-ecwid-styles' );
	}

	if ( ! ot_get_option( 'uni_color_schemes' ) ) {
		wp_register_style(
			'unitheme-asana-scheme',
			get_template_directory_uri() . '/css/scheme-default.css',
			array( 'unitheme-styles' ),
			'1.7.6',
			'screen'
		);
		wp_enqueue_style( 'unitheme-asana-scheme' );
	} else {
		$sColourScheme = ot_get_option( 'uni_color_schemes' );
		wp_register_style(
			'unitheme-asana-scheme',
			get_template_directory_uri() . '/css/scheme-' . $sColourScheme . '.css',
			array( 'unitheme-styles' ),
			'1.7.6',
			'screen'
		);
		wp_enqueue_style( 'unitheme-asana-scheme' );
	}

	wp_register_style( 'unitheme-adaptive', get_template_directory_uri() . '/css/adaptive.css', array( 'unitheme-styles' ), '1.7.6', 'screen' );
	wp_enqueue_style( 'unitheme-adaptive' );
}

add_action( 'wp_enqueue_scripts', 'uni_asana_theme_styles' );

//
function uni_asana_theme_fonts_url() {
	$fonts_url = '';

	$ot_set_google_fonts = get_theme_mod( 'ot_set_google_fonts', array() );

	if ( empty( $ot_set_google_fonts ) ) {
		$font_families   = array();
		$font_families[] = 'Lato:300,300italic,regular';
		$font_families[] = 'Montserrat:700,regular';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

// custom fonts
add_action( 'wp_head', 'uni_asana_theme_fonts_customization' );
function uni_asana_theme_fonts_customization() {
	// helps customize fonts
	if ( ot_get_option( 'uni_google_fonts' ) ) {
		$aCustomFonts        = ot_get_option( 'uni_google_fonts' );
		$ot_google_fonts     = get_theme_mod( 'ot_google_fonts', array() );
		$ot_set_google_fonts = get_theme_mod( 'ot_set_google_fonts', array() );
		$sFontNameOne        = $sFontNameTwo = '';
		if ( ! empty( $ot_set_google_fonts ) ) {
			if ( isset( $aCustomFonts[0] ) && ! empty( $aCustomFonts[0] ) && isset( $ot_google_fonts[ $aCustomFonts[0]["family"] ] ) ) {
				$sFontNameOne = $ot_google_fonts[ $aCustomFonts[0]["family"] ]['family'];
			}
			if ( isset( $aCustomFonts[1] ) && ! empty( $aCustomFonts[1] ) && isset( $ot_google_fonts[ $aCustomFonts[1]["family"] ] ) ) {
				$sFontNameTwo = $ot_google_fonts[ $aCustomFonts[1]["family"] ]['family'];
			}

			if ( $sFontNameOne != 'Lato' || $sFontNameTwo != 'Montserrat' ) {
				?>
                <style type="text/css">
                    /* regular text */
                    body, table, input, textarea, select, li, button, p, blockquote, ol, dl, form, pre, th, td, a,
                    .uni-bridallist-title, .postItemV2 h3 a, .postItemV2 h3 a:visited,
                    .postItemV2 p, .ecwid-shopping-cart .singleTitle,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-auth .ecwid-productBrowser-auth-signInLink:active,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-auth .ecwid-productBrowser-auth-signInLink,
                    .uni-bridallist-title-wrapper .uni-bridallist-title.uni-bridallist-editable input,
                    .mainMenu ul li ul li a,
                    .footerSubscribe input[type="text"],
                    .pageHeader h1,
                    .contactInfo h3, .storyDesc h3,
                    .contactInfo p, .storyDesc p,
                    .teamItemNameWrap h3,
                    .teamItem .overlay p,
                    .teamItemDesc h3,
                    .teamItemDesc p,
                    .ourValues .wrapper p,
                    .sbi_header_link,
                    .blog section.uni-container, .blogCategoryList ul li a, .blogCategoryList ul li a:visited,
                    .singleTitle, .singlePostWrap h6,
                    .singlePostWrap h1, .singlePostWrap h2,
                    .singlePostWrap h3, .singlePostWrap h4, .singlePostWrap h5,
                    .singlePostWrap h6 a, .singlePostWrap h6 a:visited,
                    .singlePostWrap h5 a, .singlePostWrap h5 a:visited,
                    .singlePostWrap h4 a, .singlePostWrap h4 a:visited,
                    .singlePostWrap h3 a, .singlePostWrap h3 a:visited,
                    .singlePostWrap h2 a, .singlePostWrap h2 a:visited,
                    .singlePostWrap table th,
                    .singlePostWrap table th a, .singlePostWrap table th a:visited,
                    .singlePostWrap table td,
                    .singlePostWrap table td a, .singlePostWrap table td a:visited,
                    .singlePostWrap p,
                    .singlePostWrap,
                    .singlePostWrap dt a, .singlePostWrap dt a:visited,
                    .singlePostWrap dd a, .singlePostWrap dd a:visited,
                    .singlePostWrap p a, .singlePostWrap p a:visited,
                    .singlePostWrap dt,
                    .singlePostWrap dd,
                    .singlePostWrap > ul li, .singlePostWrap > ol li,
                    .singlePostWrap > ol li:before,
                    .singlePostWrap p a, .singlePostWrap p a:visited, .singlePostWrap > ul li a, .singlePostWrap > ul li a:visited,
                    .singlePostWrap > ol li a, .singlePostWrap > ol li a:visited,
                    .singlePostWrap address,
                    .singlePostWrap blockquote p,
                    .singlePostWrap blockquote p a, .singlePostWrap blockquote p a:visited,
                    .singlePostTags,
                    .singleLinkPages a, .singleLinkPages a:visited, .singlePostTags a, .singlePostTags a:visited,
                    .singlePostWrap .su-list ul li,
                    .singlePostWrap .su-tabs-nav span,
                    .singlePostWrap .su-tabs-pane,
                    .singlePostWrap .su-label,
                    .logged-in-as,
                    .bypostauthor .comment-wrapper .uni-post-author,
                    .comment-metadata time,
                    .comment-content p, .comment-awaiting-moderation,
                    .comment-content p a, .comment-content p a:visited,
                    #commentform input[type="text"],
                    #commentform textarea,
                    .contactForm h3,
                    .contactFormDesc,
                    .contactForm .form-row input[type="text"], .contactForm .form-row input[type="email"], .contactForm .form-row textarea,
                    .contactForm .wpcf7-form p,
                    .wpcf7-form .wpcf7-quiz,
                    .wpcf7-form .wpcf7-text,
                    .wpcf7-form .wpcf7-range,
                    .wpcf7-form .wpcf7-date,
                    .wpcf7-form textarea,
                    .wpcf7-form select,
                    .miniCart span,
                    .miniCartItem h3 a, .miniCartItem h3 a:visited,
                    .miniCartItem .price,
                    .miniCartItem .quantity span,
                    .miniCartItem .quantity input[type="text"],
                    .miniCartSubTotal,
                    .miniCartItem dt,
                    .miniCartItem dd,
                    .miniCartEmpty p,
                    .pageTitle,
                    .sortingList span, .categoryList span,
                    .sortingList ul li a, .sortingList ul li a:visited,
                    .categoryList ul li a, .categoryList ul li a:visited,
                    .eventItemDesc h3 a, .eventItemDesc h3 a:visited,
                    .eventItemDesc p,
                    .subscribeBox h3,
                    .subscribeBox p,
                    .backToBtn, .backToBtn:visited,
                    .nextEventBox h3,
                    .eventDetailItem p,
                    .eventRegistrationWrap h3,
                    .eventRegistrationForm .form-row input[type="text"],
                    .eventRegistrationForm .form-row input[type="email"],
                    .eventRegistrationForm .form-row textarea,
                    .cartPage table th,
                    .cartPage table td,
                    .cartProduct h4 a, .cartProduct h4 a:visited,
                    .cartPage .quantity input[type="number"],
                    .cartPage .woocommerce td.product-name dl.variation dt,
                    .cartPage .woocommerce td.product-name dl.variation dd p,
                    .coupon label,
                    .coupon input[type="text"],
                    .woocommerce-page .cart-collaterals .cart_totals h2,
                    .woocommerce-cart .cart-collaterals .cart_totals tr th,
                    .woocommerce-cart .cart-collaterals .cart_totals tr td,
                    .shipping-calculator-form .selectric p,
                    .shipping-calculator-form p input[type="text"],
                    .page.woocommerce-cart .cart-empty, .uni-wishlist-empty,
                    table.uni-wishlist-table td,
                    .uni-wishlist-item-title a, .uni-wishlist-item-title a:visited,
                    .uni-wishlist-item-availability span,
                    .uni-wishlist-item-title dl.variation dt,
                    .uni-wishlist-item-title dl.variation dd,
                    .checkoutPage h3,
                    .checkoutPage p .selectric p,
                    .checkoutPage .mcell p label,
                    .checkoutPage .fcell p label,
                    .checkoutPage .fcell p input[type="tel"],
                    .checkoutPage .fcell p input[type="email"],
                    .checkoutPage .fcell p input[type="password"],
                    .checkoutPage .mcell p textarea,
                    .checkoutPage .mcell p input[type="text"],
                    .checkoutPage .fcell p input[type="text"],
                    .checkoutPage .woocommerce .scell table.shop_table tfoot th,
                    .checkoutPage .woocommerce .scell table.shop_table tfoot td,
                    .cartItem h4 a, .cartItem h4 a:visited,
                    .cartItem p,
                    .payment_methods li label,
                    body .woocommerce form.checkout_coupon p.form-row input.input-text,
                    body .woocommerce form.login p.form-row input.input-text,
                    body.page.woocommerce-account .singlePostWrap address,
                    .page.woocommerce-account form label,
                    .page.woocommerce-account form p.form-row input.input-text,
                    .page.woocommerce-account form p.form-row textarea,
                    .page.woocommerce-account form p.form-row .selectric p,
                    .productDesc h1,
                    .productDesc p.price,
                    .productDesc p,
                    .productDesc .product_meta > span,
                    .productDesc .product_meta > span span,
                    .productDesc .product_meta > span a, .productDesc .product_meta > span a:visited,
                    .uni_cpo_fields_label,
                    .uni_cpo_fields_container .selectric p,
                    .productDesc table.variations .selectric p,
                    .uni_cpo_fields_container .selectric .button,
                    .productDesc table.variations .selectric .button,
                    .variations select,
                    form.woocommerce-ordering select,
                    .single-product .woocommerce-tabs #tab-reviews p,
                    .single-product .woocommerce-tabs #tab-description p,
                    .woocommerce #tab-reviews #reviews #comments ol.commentlist li .comment-text p.meta strong,
                    .woocommerce-review-link, .woocommerce-review-link:hover,
                    .woocommerce #tab-additional_information table.shop_attributes th,
                    .woocommerce #tab-additional_information table.shop_attributes td,
                    .uni-wishlist-link, .uni-wishlist-link:visited,
                    .classesCallendar .fc-toolbar h2,
                    .classesCallendar .fc-day-header,
                    .classesCallendar .fc-event,
                    .classesCallendar td.fc-time,
                    .classesDescPopup h3,
                    .classesDescWrap p,
                    .classesInstructorWrap h4,
                    .page404Wrap p,
                    .thankYouBox h3,
                    .thankYouWrap .order_details li,
                    .thankYouWrap h2,
                    .thankYouWrap .order_details thead th,
                    .thankYouWrap .order_details tbody td,
                    .thankYouWrap .order_details tbody td strong, .thankYouWrap .order_details tbody td a, .thankYouWrap .order_details tbody td a:visited,
                    .thankYouWrap .order_details tfoot th, .thankYouWrap .order_details tfoot td,
                    .thankYouWrap .order_details tbody td .variation dt, .thankYouWrap .order_details tbody td .variation dd,
                    .customer_details dt,
                    .customer_details dd,
                    .thankYouWrap .col2-set.addresses h3,
                    .thankYouWrap .col2-set.addresses address,
                    .membershipCardItem h3, .ecwid-SearchPanel-field,
                    .membershipCard, .checkoutPage .woocommerce .scell table.shop_table tbody td.product-name > p, .checkoutPage .scell label[for="payment_method_paypal"] a,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-categoryPath, html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-categoryPath,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-categoryPath span.gwt-InlineLabel,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-categoryPath a,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-categoryPath a:active,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-categoryPath a:visited,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-productNameLink a,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-productNameLink a:active,
                    html#ecwid_html body#ecwid_body.chameleon div.ecwid-productBrowser-productNameLink a:visited,
                    html#ecwid_html body#ecwid_body .ecwid a.ecwid-poweredBy,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-details-rightPanel div.ecwid-productBrowser-sku,
                    html#ecwid_html body#ecwid_body .ecwid span.ecwid-productBrowser-price-value,
                    html#ecwid_html body#ecwid_body .ecwid span.gwt-InlineLabel,
                    html#ecwid_html body#ecwid_body td.ecwid-productBrowser-cart-itemsTable-headerCell,
                    html#ecwid_html body#ecwid_body .ecwid-responsive div.ecwid-productBrowser-cart .ecwid-productBrowser-cart-itemsTable-cell-descr div.ecwid-productBrowser-sku,
                    html#ecwid_html body#ecwid_body div.ecwid-results-topPanel-sortByPanel select.gwt-ListBox,
                    html#ecwid_html body#ecwid_body div.ecwid-results-topPanel div.ecwid-results-topPanel-itemsCountLabel,
                    html#ecwid_html body#ecwid_body div.ecwid-results-topPanel div .ecwid-results-topPanel-viewAsPanel,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-productsList-details div.ecwid-productBrowser-sku,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser-productsList-details div.ecwid-productBrowser-price-list, .rssSummary, .widget_rss ul li cite,
                    .relatedPostsItemV2, .relatedPostsItemV2 h4 a, .relatedPostsItemV2 h4 a:visited,
                    .sidebar-widget li, .sidebar-widget li a, .sidebar-widget li a:visited, #wp-calendar caption, #wp-calendar tbody td, #wp-calendar tfoot td a, #wp-calendar tfoot td a:visited,
                    .membershipCardItem p {
                        font-family: '<?php echo esc_attr( $sFontNameOne ); ?>' !important;
                    }

                    .woocommerce-breadcrumb,
                    .woocommerce-breadcrumb a, .woocommerce-breadcrumb a:visited,
                    .checkoutPage .woocommerce .scell table.shop_table tbody td.product-name,
                    .checkoutPage .woocommerce .scell table.shop_table tbody td.product-total,
                    .checkoutPage .woocommerce .scell table.shop_table tbody td .variation dd,
                    .checkoutPage .woocommerce .scell table.shop_table tbody td .variation dt,
                    #review_form #commentform p label,
                    #uni_popup, .contactForm .wpcf7-validation-errors,
                    .wpcf7-response-output.wpcf7-mail-sent-ok,
                    .woocommerce .woocommerce-info, .woocommerce .woocommerce-error, .woocommerce .woocommerce-message,
                    .woocommerce .woocommerce-message .button.wc-forward,
                    .woocommerce .woocommerce-info a, .woocommerce .woocommerce-info a:visited,
                    .woocommerce .woocommerce-message a, .woocommerce .woocommerce-message a:visited,
                    .woocommerce .woocommerce-error li {
                        font-family: '<?php echo esc_attr( $sFontNameOne ); ?>' !important;
                    }

                    /* headings */
                    .uni-bridallist-title-wrapper .uni-bridallist-title.uni-bridallist-editable button[type="submit"],
                    .uni-bridallist-title-wrapper .uni-bridallist-title.uni-bridallist-editable button[type="cancel"],
                    html#ecwid_html body#ecwid_body.chameleon .ecwid-btn--secondary, #wp-calendar thead th, a.rsswidget,
                    html#ecwid_html body#ecwid_body div.ecwid-productBrowser .ecwid-btn--primary, .sidebar-widget .search-form .search-field,
                    .postPrev, .postNext, .relatedPostsV2 h3, .categoryLink, .categoryLink:visited,
                    html#ecwid_html body#ecwid_body.ecwid-shopping-cart .ecwid-SearchPanel .ecwid-SearchPanel-button,
                    .mainMenu > ul > li a,
                    .mainMenu > ul > li a:visited,
                    .learnMore, .learnMore:visited,
                    .mainItemDesc .viewMore, .mainItemDesc .viewMore:visited,
                    .gridItemDesc .viewMore,
                    .postItemTime,
                    .classesCategory,
                    .viewClasses, .viewClasses:visited,
                    .loadMoreItems, .loadMoreItems:visited,
                    .showAllItems, .showAllItems:visited,
                    .pagination ul li a, .pagination ul li a:visited,
                    .pagination ul li.current, .woocommerce-pagination ul li span.current,
                    .footerMenu li a, .footerMenu li a:visited,
                    .singleLinkPages,
                    .singlePostTags span,
                    .singlePostWrap .su-quote-cite a,
                    .singlePostWrap .su-divider a,
                    .singlePostWrap .su-heading-style-default .su-heading-inner,
                    .singlePostWrap .su-service-title,
                    .singlePostWrap .su-spoiler-title,
                    .singlePostWrap .su-carousel .su-carousel-slide-title,
                    .singlePostWrap .su-slider-slide-title,
                    .commentsBox h2, .commentsBox h3,
                    .commentsBox h3 a, .commentsBox h3 a:visited,
                    .comment-edit-link, .comment-edit-link:visited, .comment-reply-link, .comment-reply-link:visited,
                    .logged-in-as a, .logged-in-as a:visited,
                    .comment-wrapper cite,
                    .comment-wrapper cite a,
                    #commentform #submit,
                    .submitContactFormBtn,
                    .wpcf7-form input[type="submit"],
                    .productFilter li a, .productFilter li a:visited,
                    .miniCartPopupHead h3,
                    .btnViewCart, .btnViewCart:visited,
                    .btnCheckout, .btnCheckout:visited,
                    .eventItemTime,
                    .eventLearnMore, .eventLearnMore:visited,
                    .showMoreEvents, .showMoreEvents:visited,
                    .subscribeBox form input[type="text"],
                    .subscribeSubmit,
                    .nextEventBtn, .nextEventBtn:visited,
                    .singleEventJoinBtnWrap a, .singleEventJoinBtnWrap a:visited,
                    .submitEventRegistrationBtn,
                    .woocommerce-cart .wc-proceed-to-checkout .checkout-button,
                    .updateCartBtn,
                    .page.woocommerce-cart .return-to-shop a.button,
                    .page-template-templ-wishlist .return-to-shop a.button,
                    .button.product_type_, .button.add_to_cart_button,
                    #place_order,
                    body .woocommerce form.checkout_coupon p.form-row input.button,
                    body .woocommerce form.login p.form-row input.button,
                    body.page.woocommerce-account .shop_table.shop_table_responsive.my_account_orders .button.view,
                    .page.woocommerce-account form p input.button,
                    .productDesc form.cart .single_add_to_cart_button,
                    .page404Wrap a.homePage, .page404Wrap a.homePage:visited,
                    .postItemV2ReadMoreWrap a, .postItemV2ReadMoreWrap a:visited,
                    .sidebar-widget .widgettitle, .sidebar-widget select,
                    .membership-card-order, .membership-card-order:visited {
                        font-family: '<?php echo esc_attr( $sFontNameTwo ); ?>' !important;
                    }

                    .woocommerce-pagination ul li a, .woocommerce-pagination ul li a:visited,
                    .pagination ul li.threeDot,
                    .coupon input[name="apply_coupon"],
                    .actions input[name="update_cart"],
                    .shipping-calculator-form p button,
                    .single-product .woocommerce-tabs .tabs li a,
                    .single-product .woocommerce-tabs .tabs li a:visited,
                    #tab-additional_information h2,
                    #review_form_wrapper .comment-reply-title,
                    .single-product .woocommerce-tabs #tab-reviews h2,
                    .single-product .woocommerce-tabs #tab-description h2,
                    .woocommerce #tab-reviews #reviews #comments ol.commentlist li .comment-text p.meta time,
                    #review_form #commentform #submit {
                        font-family: '<?php echo esc_attr( $sFontNameTwo ); ?>' !important;
                    }
                </style>
				<?php
			}
		}
	}
}

// customization of sticky header
add_action( 'wp_head', 'uni_asana_theme_custom_styles_sticky_header' );
function uni_asana_theme_custom_styles_sticky_header() {
	if ( ot_get_option( 'uni_nav_white_enable' ) && ot_get_option( 'uni_nav_white_enable' ) == 'on'
	     && ( ot_get_option( 'uni_sticky_nav_white_enable' ) || ot_get_option( 'uni_sticky_nav_link_color' ) || ot_get_option( 'uni_sticky_nav_link_hover_color' ) ) ) { ?>
        <style type="text/css">
            html body.fixedMainMenu #header .headerWrap {
                background: <?php echo ( ot_get_option('uni_sticky_nav_bg_color') ) ? ot_get_option('uni_sticky_nav_bg_color') : '#ffffff' ?> !important;
            }

            html body.fixedMainMenu #header .mainMenu ul li a {
                color: <?php echo ( ot_get_option('uni_sticky_nav_link_color') ) ? ot_get_option('uni_sticky_nav_link_color') : '#7f7f7f' ?>;
            }

            html body.fixedMainMenu #header .mainMenu ul li.current-menu-item a,
            html body.fixedMainMenu #header .mainMenu ul li a:hover {
                color: <?php echo ( ot_get_option('uni_sticky_nav_link_hover_color') ) ? ot_get_option('uni_sticky_nav_link_hover_color') : '#333333' ?>;
            }
        </style>
	<?php }
}

// customization of floating header
add_action( 'wp_head', 'uni_asana_theme_custom_styles_floating_header' );
function uni_asana_theme_custom_styles_floating_header() {
	// in transparent state
	if ( ot_get_option( 'uni_nav_white_enable' ) && ot_get_option( 'uni_nav_white_enable' ) == 'off'
	     && ot_get_option( 'uni_nav_floating_custom_styles_enable' ) && ot_get_option( 'uni_nav_floating_custom_styles_enable' ) == 'on'
	     && ( ot_get_option( 'uni_floating_nav_bg_color_transparent' ) || ot_get_option( 'uni_floating_nav_border_transparent' )
	          || ot_get_option( 'uni_floating_nav_link_color_transparent' ) || ot_get_option( 'uni_floating_nav_link_hover_color_transparent' ) ) ) { ?>
        <style type="text/css">
            #header .headerWrap {
                background: <?php echo ( ot_get_option('uni_floating_nav_bg_color_transparent') ) ? ot_get_option('uni_floating_nav_bg_color_transparent') : 'rgba(255,255,255,0.01)' ?>;
                border-bottom: 1px solid <?php echo ( ot_get_option('uni_floating_nav_border_transparent') ) ? ot_get_option('uni_floating_nav_border_transparent') : 'rgba(255,255,255,0.2)' ?>;
            }

            .mainMenu > ul > li a, .mainMenu > ul > li a:visited {
                color: <?php echo ( ot_get_option('uni_floating_nav_link_color_transparent') ) ? ot_get_option('uni_floating_nav_link_color_transparent') : '#ffffff' ?>;
            }

            .mainMenu > ul > li a:hover {
                color: <?php echo ( ot_get_option('uni_floating_nav_link_hover_color_transparent') ) ? ot_get_option('uni_floating_nav_link_hover_color_transparent') : '#ffffff' ?>;
            }
        </style>
	<?php }

	// in non-transparent state
	if ( ot_get_option( 'uni_nav_white_enable' ) && ot_get_option( 'uni_nav_white_enable' ) == 'off'
	     && ot_get_option( 'uni_nav_floating_custom_styles_enable' ) && ot_get_option( 'uni_nav_floating_custom_styles_enable' ) == 'on'
	     && ( ot_get_option( 'uni_floating_nav_bg_color' ) || ot_get_option( 'uni_floating_nav_link_color' )
	          || ot_get_option( 'uni_floating_nav_link_hover_color' ) ) ) { ?>
        <style type="text/css">
            #header .headerWrap.is-sticky,
            html body.home-slider-disabled #header .headerWrap {
                background: <?php echo ( ot_get_option('uni_floating_nav_bg_color') ) ? ot_get_option('uni_floating_nav_bg_color') : '#ffffff' ?>;
            }

            .page-template-templ-blog #header .headerWrap, .page-template-templ-blog-with-sidebar #header .headerWrap, .blog #header .headerWrap,
            .search #header .headerWrap, .archive.category #header .headerWrap, .archive.date #header .headerWrap, .archive.tag #header .headerWrap, .archive.author #header .headerWrap,
            .single-post #header .headerWrap, .single-post-with-sidebar #header .headerWrap,
            .page.page-template-default:not(.ecwid-shopping-cart) #header .headerWrap,
            .page.woocommerce-account #header .headerWrap, .error404 #header .headerWrap {
                background: <?php echo ( ot_get_option('uni_floating_nav_bg_color') ) ? ot_get_option('uni_floating_nav_bg_color') : '#ffffff' ?>;
            }

            #header .headerWrap.is-sticky .mainMenu > ul > li a, #header .headerWrap.is-sticky .mainMenu > ul > li a:visited,
            html body.home-slider-disabled #header .headerWrap .mainMenu > ul > li a, html body.home-slider-disabled #header .headerWrap .mainMenu > ul > li a:visited,
            .page-template-templ-blog .mainMenu > ul > li a, .page-template-templ-blog .mainMenu > ul > li a:visited,
            .page-template-templ-blog-with-sidebar .mainMenu > ul > li a, .page-template-templ-blog-with-sidebar .mainMenu > ul > li a:visited,
            .blog .mainMenu > ul > li a, .blog .mainMenu > ul > li a:visited,
            .search .mainMenu > ul > li a, .search .mainMenu > ul > li a:visited,
            .archive.category .mainMenu > ul > li a, .archive.category .mainMenu > ul > li a:visited,
            .archive.date .mainMenu > ul > li a, .archive.date .mainMenu > ul > li a:visited,
            .archive.tag .mainMenu > ul > li a, .archive.tag .mainMenu > ul > li a:visited,
            .archive.author .mainMenu > ul > li a, .archive.author .mainMenu > ul > li a:visited,
            .single-post .mainMenu > ul > li a, .single-post .mainMenu > ul > li a:visited,
            .single-post-with-sidebar .mainMenu > ul > li a, .single-post-with-sidebar .mainMenu > ul > li a:visited,
            .page.page-template-default:not(.ecwid-shopping-cart) .mainMenu > ul > li a, .page.page-template-default:not(.ecwid-shopping-cart) .mainMenu > ul > li a:visited,
            .page.woocommerce-account .mainMenu > ul > li a, .page.woocommerce-account .mainMenu > ul > li a:visited,
            .error404 .mainMenu > ul > li a, .error404 .mainMenu > ul > li a:visited {
                color: <?php echo ( ot_get_option('uni_floating_nav_link_color') ) ? ot_get_option('uni_floating_nav_link_color') : '#ffffff' ?>;
            }

            #header .headerWrap.is-sticky .mainMenu > ul > li.current-menu-item a, #header .headerWrap.is-sticky .mainMenu > ul > li a:hover,
            html body.home-slider-disabled #header .headerWrap .mainMenu > ul > li.current-menu-item a, html body.home-slider-disabled #header .headerWrap .mainMenu > ul > li a:hover,
            .page-template-templ-blog .mainMenu > ul > li.current-menu-item a, .page-template-templ-blog .mainMenu > ul > li a:hover,
            .page-template-templ-blog-with-sidebar .mainMenu > ul > li.current-menu-item a, .page-template-templ-blog-with-sidebar .mainMenu > ul > li a:hover,
            .blog .mainMenu > ul > li.current-menu-item a, .blog .mainMenu > ul > li a:hover,
            .search .mainMenu > ul > li.current-menu-item a, .search .mainMenu > ul > li a:hover,
            .archive.category .mainMenu > ul > li.current-menu-item a, .archive.category .mainMenu > ul > li a:hover,
            .archive.date .mainMenu > ul > li.current-menu-item a, .archive.date .mainMenu > ul > li a:hover,
            .archive.tag .mainMenu > ul > li.current-menu-item a, .archive.tag .mainMenu > ul > li a:hover,
            .archive.author .mainMenu > ul > li.current-menu-item a, .archive.author .mainMenu > ul > li a:hover,
            .single-post .mainMenu > ul > li.current-menu-item a, .single-post .mainMenu > ul > li a:hover,
            .single-post-with-sidebar .mainMenu > ul > li.current-menu-item a, .single-post-with-sidebar .mainMenu > ul > li a:hover,
            .page.page-template-default:not(.ecwid-shopping-cart) .mainMenu > ul > li.current-menu-item a, .page.page-template-default:not(.ecwid-shopping-cart) .mainMenu > ul > li a:hover,
            .page.woocommerce-account .mainMenu > ul > li.current-menu-item a, .page.woocommerce-account .mainMenu > ul > li a:hover,
            .error404 .mainMenu > ul > li.current-menu-item a, .error404 .mainMenu > ul > li a:hover {
                color: <?php echo ( ot_get_option('uni_floating_nav_link_hover_color') ) ? ot_get_option('uni_floating_nav_link_hover_color') : '#ffffff' ?>;
            }
        </style>
	<?php }
}

//
add_action( 'admin_enqueue_scripts', 'uni_asana_theme_admin_script', 10, 1 );
function uni_asana_theme_admin_script( $hook ) {
	wp_enqueue_script( 'unitheme-admin-script', get_template_directory_uri() . '/js/uni-admin.js', array( 'jquery' ), '1.7.5' );
}

// outputs 'header' tag with theme's menu and logo
function uni_asana_theme_header_div_output() {
	if ( ot_get_option( 'uni_preloader_disable' ) !== 'off' ) {
		?>
        <div class="loaderWrap">
            <div class="la-ball-clip-rotate la-dark">
                <div></div>
            </div>
        </div>
	<?php } ?>
    <header id="header">
        <div class="headerWrap clear">

			<?php uni_asana_theme_the_custom_logo_output() ?>

			<?php wp_nav_menu( array(
				'container'       => 'nav',
				'container_class' => 'mainMenu',
				'menu_class'      => 'clear',
				'theme_location'  => 'primary',
				'depth'           => 3,
				'fallback_cb'     => 'uni_asana_theme_nav_fallback'
			) ); ?>

            <span class="showMobileMenu">
				<span></span>
				<span></span>
				<span></span>
				<span></span>
			</span>
        </div>
    </header>
	<?php
}

//
function uni_asana_theme_the_custom_logo_output() {

	$sLogoType          = ot_get_option( 'uni_logo_type' );
	$iLogoAThumbId      = ( ot_get_option( 'uni_logo_a' ) ) ? ot_get_option( 'uni_logo_a' ) : '';
	$iLogoBThumbId      = ( ot_get_option( 'uni_logo_b' ) ) ? ot_get_option( 'uni_logo_b' ) : '';
	$iImageHeight       = ( ot_get_option( 'uni_logo_height' ) ) ? intval( ot_get_option( 'uni_logo_height' ) ) : '';
	$iMainMenuMarginTop = ( ot_get_option( 'uni_menu_top_margin' ) ) ? intval( ot_get_option( 'uni_menu_top_margin' ) ) : 37;
	$bRetinaScreen      = false;

	$sLogoAId = ot_get_option( 'uni_custom_logo_a' );
	$sLogoBId = ot_get_option( 'uni_custom_logo_b' );

	?>
    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url" class="logo">
		<?php
		if ( empty( $sLogoType ) || $sLogoType === 'off' ) {
			uni_asana_theme_the_custom_logo_a();
			uni_asana_theme_the_custom_logo_b();
		} else if ( $sLogoType === 'on' ) {
			$sSvgLogo = ot_get_option( 'uni_logo_svg' );
			if ( isset( $sSvgLogo ) && ! empty( $sSvgLogo ) ) {
				echo ot_get_option( 'uni_logo_svg' );
			} else {
				?>
                <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" x="0px"
                     y="0px" width="122px" height="32px" viewBox="0 0 122 32" enable-background="new 0 0 122 32"
                     xml:space="preserve">
    			    <path fill="#333333"
                          d="M31.426 11.797c-0.161-0.59-0.355-1.173-0.589-1.735c-0.449-1.152-1.045-2.225-1.748-3.223 c-0.442-0.643-0.938-1.245-1.467-1.808C24.695 1.9 20.6 0 16 0C11.413 0 7.3 1.9 4.4 5 C3.832 5.6 3.3 6.2 2.9 6.839c-0.703 0.998-1.292 2.07-1.748 3.223c-0.234 0.563-0.422 1.146-0.583 1.7 C0.188 13.1 0 14.5 0 15.997c0 0.7 0 1.4 0.1 2.109c0.014 0.1 0 0.2 0.1 0.4 c0.06 0.4 0.1 0.9 0.3 1.348c0.013 0 0 0.1 0 0.107h31.004c0.014-0.041 0.014-0.067 0.02-0.107 c0.121-0.436 0.214-0.885 0.275-1.341c0.02-0.12 0.04-0.241 0.047-0.361c0.114-0.697 0.154-1.4 0.154-2.109 C31.989 14.5 31.8 13.1 31.4 11.797z M1.983 18.106C1.909 17.7 1.9 17.3 1.8 16.9 c-0.02-0.295-0.034-0.603-0.034-0.903c0-0.302 0.014-0.616 0.034-0.904c0.067-1.119 0.268-2.197 0.569-3.223 c0.201-0.623 0.435-1.226 0.703-1.809C3.65 8.9 4.3 7.8 5.2 6.839c0.563-0.663 1.172-1.266 1.842-1.808 c2.438-2.017 5.573-3.223 8.982-3.223c3.396 0 6.5 1.2 9 3.223c0.676 0.5 1.3 1.1 1.8 1.8 c0.824 1 1.5 2.1 2.1 3.223c0.274 0.6 0.5 1.2 0.7 1.809c0.302 1 0.5 2.1 0.6 3.2 c0.02 0.3 0 0.6 0 0.904c0 0.301-0.007 0.608-0.027 0.903c-0.034 0.409-0.074 0.811-0.141 1.206H1.983z M8.607 30.2 C10.824 31.3 13.3 32 16 32c2.666 0 5.17-0.671 7.381-1.822H8.607z M30.75 22.133c-0.254 0.623-0.542 1.239-0.884 1.8 H2.124c-0.342-0.563-0.636-1.179-0.891-1.802H30.75z M28.338 26.159c-0.228 0.281-0.469 0.535-0.71 0.8 c-0.328 0.348-0.669 0.683-1.031 1.004H5.392c-0.362-0.321-0.704-0.656-1.038-1.004c-0.241-0.269-0.482-0.522-0.704-0.804H28.338z M55.652 23.104l-1.306-3.034h-5.894l-1.306 3.034h-3.342l6.075-14.061h3.041l6.075 14.061H55.652z M51.406 13.23l-1.768 4.1 h3.523L51.406 13.23z M64.814 11.851c-0.295 0.247-0.455 0.575-0.455 0.984c0 0.4 0.2 0.7 0.6 1 c0.361 0.2 1.2 0.5 2.5 0.852c1.34 0.3 2.4 0.8 3.1 1.479c0.75 0.7 1.1 1.6 1.1 2.9 c0 1.261-0.469 2.285-1.42 3.069c-0.951 0.783-2.184 1.172-3.737 1.172c-2.224 0-4.233-0.824-6.008-2.472l1.868-2.292 c1.514 1.3 2.9 2 4.2 1.99c0.575 0 1.031-0.12 1.353-0.375c0.335-0.247 0.509-0.582 0.509-1.005s-0.188-0.757-0.535-1.005 c-0.349-0.248-1.045-0.503-2.063-0.757c-1.634-0.389-2.84-0.891-3.59-1.514c-0.764-0.623-1.146-1.608-1.146-2.94 c0-1.333 0.482-2.365 1.44-3.089c0.964-0.723 2.156-1.085 3.59-1.085c0.938 0 1.9 0.2 2.8 0.5 c0.938 0.3 1.8 0.8 2.5 1.366l-1.594 2.298c-1.219-0.931-2.479-1.393-3.791-1.393 C65.538 11.5 65.1 11.6 64.8 11.851z M85.229 23.104l-1.313-3.034h-5.895l-1.313 3.034h-3.336l6.082-14.061h3.041 l6.068 14.061H85.229z M80.983 13.23l-1.782 4.079h3.537L80.983 13.23z M101.036 9.043h3.135v14.061h-3.135l-6.697-8.809v8.809 h-3.135V9.043h2.934l6.898 9.057V9.043z M118.665 23.104l-1.313-3.034h-5.894l-1.313 3.034h-3.322l6.068-14.061h3.04L122 23.1 H118.665z M114.418 13.23l-1.768 4.079h3.522L114.418 13.23z"/>
    			</svg>
			<?php }
		} ?>
    </a>

    <style type="text/css">
        .mainMenu {
            margin-top: <?php echo intval($iMainMenuMarginTop) ?>px;
        }

        #header .is-sticky .mainMenu {
            margin-top: <?php echo intval($iMainMenuMarginTop - 15) ?>px;
        }
    </style>
	<?php
}

//
function uni_asana_theme_the_custom_logo_a( $blog_id = 0 ) {
	echo uni_asana_theme_get_custom_logo_a( $blog_id );
}

//
function uni_asana_theme_get_custom_logo_a( $blog_id = 0 ) {
	$html = '';

	if ( is_multisite() && (int) $blog_id !== get_current_blog_id() ) {
		switch_to_blog( $blog_id );
	}

	$sLogoAId = ot_get_option( 'uni_custom_logo_a' );

	// Logo A
	if ( $sLogoAId ) {
		$html .= wp_get_attachment_image( $sLogoAId, 'full', false, array(
				'class'    => 'logo-black uni-custom-logo-a',
				'itemprop' => 'logo'
			)
		);
	} else {
		$html .= '<img class="logo-black uni-custom-logo-a" src="' . esc_url( get_template_directory_uri() . '/images/logo-black.png' ) . '" alt="' . esc_attr( get_bloginfo( 'description' ) ) . '">';
	}

	if ( is_multisite() && ms_is_switched() ) {
		restore_current_blog();
	}

	return apply_filters( 'uni_asana_theme_get_custom_logo_a', $html );
}

//
function uni_asana_theme_the_custom_logo_b( $blog_id = 0 ) {
	echo uni_asana_theme_get_custom_logo_b( $blog_id );
}

//
function uni_asana_theme_get_custom_logo_b( $blog_id = 0 ) {
	$html = '';

	if ( is_multisite() && (int) $blog_id !== get_current_blog_id() ) {
		switch_to_blog( $blog_id );
	}

	$sLogoBId = ot_get_option( 'uni_custom_logo_b' );

	// Logo B
	if ( $sLogoBId ) {
		$html .= wp_get_attachment_image( $sLogoBId, 'full', false, array(
				'class'    => 'logo-white uni-custom-logo-b',
				'itemprop' => 'logo',
			)
		);
	} else {
		$html .= '<img class="logo-white uni-custom-logo-b" src="' . get_template_directory_uri() . '/images/logo-white.png" alt="' . esc_attr( get_bloginfo( 'description' ) ) . '">';
	}

	if ( is_multisite() && ms_is_switched() ) {
		restore_current_blog();
	}

	return apply_filters( 'uni_asana_theme_get_custom_logo_b', $html );
}

// mobile menu
add_filter( 'wp_footer', 'uni_asana_theme_mobile_menu_output', 10 );
function uni_asana_theme_mobile_menu_output() {
	?>
    <div class="mobileMenu">
		<?php wp_nav_menu( array(
			'container'       => '',
			'container_class' => '',
			'menu_class'      => '',
			'theme_location'  => 'primary',
			'depth'           => 3,
			'fallback_cb'     => ''
		) ); ?>
    </div>
	<?php
}

// mailchimp form in the footer
function uni_asana_theme_mailchimp_footer_form_output() {

	if ( ot_get_option( 'uni_mailchimp_footer_enable' ) == 'on' ) { ?>
        <div class="footerSubscribe">
            <form action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" role="form" method="post"
                  class="uni_form">
                <input type="hidden" name="action" value="uni_asana_theme_mailchimp_subscribe_user"/>
                <input type="text" name="uni_input_email" size="20" value=""
                       placeholder="<?php esc_html_e( 'Your email', 'asana' ); ?>" data-parsley-required="true"
                       data-parsley-trigger="change focusout submit" data-parsley-type="email">
                <input class="btnSubscribe uni_input_submit" type="button"
                       value="<?php esc_html_e( 'Subscribe', 'asana' ); ?>">
            </form>
        </div>
		<?php
	}

}

// price order form in the footer
add_filter( 'wp_footer', 'uni_asana_theme_price_form_output', 10 );
function uni_asana_theme_price_form_output() {

	if ( ( ot_get_option( 'uni_home_membership_cards_enable' ) == 'on' && is_page_template( 'templ-home.php' ) ) || is_page_template( 'templ-prices.php' ) ) { ?>
        <div id="membershipCardOrderPopup" class="eventRegistrationWrap">
            <h3 id="uni_price_title"><?php esc_html_e( 'Order form', 'asana' ); ?></h3>
            <p class="membershipCardOrderMsg"><?php esc_html_e( 'Please fill out the form and we\'ll get back to you asap', 'asana' ); ?></p>
            <form action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" method="post"
                  class="eventRegistrationForm clear uni_form">
                <input type="hidden" name="uni_contact_nonce" value="<?php echo wp_create_nonce( 'uni_nonce' ) ?>"/>
                <input type="hidden" name="action" value="uni_asana_theme_price_form"/>
                <input type="hidden" name="uni_price_id" value=""/>

                <div class="form-row form-row-first">
                    <input class="formInput" type="text" name="uni_contact_firstname" value=""
                           placeholder="<?php esc_html_e( 'First Name', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="form-row form-row-last">
                    <input class="formInput" type="text" name="uni_contact_lastname" value=""
                           placeholder="<?php esc_html_e( 'Last Name', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="form-row form-row-first">
                    <input class="formInput" type="text" name="uni_contact_email" value=""
                           placeholder="<?php esc_html_e( 'Your Email', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit" data-parsley-type="email">
                </div>
                <div class="form-row form-row-last">
                    <input class="formInput" type="text" name="uni_contact_phone" value=""
                           placeholder="<?php esc_html_e( 'Phone Number', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="clear"></div>
                <div class="form-row">
                    <textarea class="formTextarea" name="uni_contact_msg" id="" cols="30" rows="10"
                              placeholder="<?php esc_html_e( 'Message', 'asana' ) ?>" data-parsley-required="true"
                              data-parsley-trigger="change focusout submit"></textarea>
                </div>
				<?php if ( ot_get_option( 'uni_form_msg_bottom_order_form_enable' ) && ot_get_option( 'uni_form_msg_bottom_order_form_enable' ) === 'on' ) { ?>
                    <div class="popupMsg">
                        <p><?php echo ( ot_get_option( 'uni_form_msg_bottom_order_form_text' ) ) ? ot_get_option( 'uni_form_msg_bottom_order_form_text' ) : ''; ?></p>
                    </div>
				<?php } ?>
                <input class="submitEventRegistrationBtn uni_input_submit" type="button"
                       value="<?php esc_html_e( 'Send', 'asana' ) ?>">
            </form>
        </div>
		<?php
	}
}

// join event form in the footer
add_filter( 'wp_footer', 'uni_asana_theme_join_form_output', 10 );
function uni_asana_theme_join_form_output() {

	global $post;
	$aCustomData = get_post_custom( $post->ID );
	if ( ( ! empty( $aCustomData['uni_local_events_join_on'][0] ) && $aCustomData['uni_local_events_join_on'][0] == 'on' )
	     || ( ot_get_option( 'uni_events_join_on' ) == 'on' && empty( $aCustomData['uni_local_events_join_on'][0] ) ) ) {
		?>
        <div id="eventRegistrationPopup" class="eventRegistrationWrap">
            <h3><?php echo ( ! empty( $aCustomData['uni_local_events_button_text'][0] ) ) ? esc_html( $aCustomData['uni_local_events_button_text'][0] ) : esc_html__( 'Join event', 'asana' ); ?></h3>

            <form action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" method="post"
                  class="eventRegistrationForm clear uni_form">
                <input type="hidden" name="uni_contact_nonce" value="<?php echo wp_create_nonce( 'uni_nonce' ) ?>"/>
                <input type="hidden" name="action" value="uni_asana_theme_join_event_form"/>
                <input type="hidden" name="event_id" value="<?php echo get_the_ID() ?>"/>

                <div class="form-row form-row-first">
                    <input class="formInput" type="text" name="uni_contact_firstname" value=""
                           placeholder="<?php esc_html_e( 'First Name', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="form-row form-row-last">
                    <input class="formInput" type="text" name="uni_contact_lastname" value=""
                           placeholder="<?php esc_html_e( 'Last Name', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="form-row form-row-first">
                    <input class="formInput" type="text" name="uni_contact_email" value=""
                           placeholder="<?php esc_html_e( 'Your Email', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit" data-parsley-type="email">
                </div>
                <div class="form-row form-row-last">
                    <input class="formInput" type="text" name="uni_contact_phone" value=""
                           placeholder="<?php esc_html_e( 'Phone Number', 'asana' ) ?>" data-parsley-required="true"
                           data-parsley-trigger="change focusout submit">
                </div>
                <div class="clear"></div>
                <div class="form-row">
                    <textarea class="formTextarea" name="uni_contact_msg" id="" cols="30" rows="10"
                              placeholder="<?php esc_html_e( 'Message', 'asana' ) ?>" data-parsley-required="true"
                              data-parsley-trigger="change focusout submit"></textarea>
                </div>
				<?php if ( ot_get_option( 'uni_form_msg_bottom_join_event_enable' ) && ot_get_option( 'uni_form_msg_bottom_join_event_enable' ) === 'on' ) { ?>
                    <div class="popupMsg">
                        <p><?php echo ( ot_get_option( 'uni_form_msg_bottom_join_event_text' ) ) ? ot_get_option( 'uni_form_msg_bottom_join_event_text' ) : ''; ?></p>
                    </div>
				<?php } ?>
                <input class="submitEventRegistrationBtn uni_input_submit" type="button"
                       value="<?php esc_html_e( 'Send', 'asana' ) ?>">
            </form>

        </div>
		<?php
	}
}

// outputs social icons in the footer
function uni_asana_theme_footer_social_icons_output() {
	?>
    <div class="footerSocial clear">
		<?php
		$aSocialLinks = maybe_unserialize( ot_get_option( 'uni_social_links_list' ) );
		if ( isset( $aSocialLinks ) && is_array( $aSocialLinks ) && ! empty( $aSocialLinks ) ) {
			foreach ( $aSocialLinks as $aLink ) {
				?>
                <a href="<?php echo esc_url( $aLink['uni_s_icon_link'] ) ?>" target="_blank">
                    <i class="<?php echo esc_attr( $aLink['uni_s_icon_type'] ) ?>"></i>
					<?php echo esc_html( $aLink['uni_s_icon_title'] ) ?>
                </a>
				<?php
			}
		} else {  // fallback
			?>
			<?php if ( ot_get_option( 'uni_email_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_email_link' ) ) ?>" target="_blank"><i
                            class="fa fa-envelope"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_fb_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_fb_link' ) ) ?>" target="_blank"><i
                            class="fa fa-facebook"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_tw_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_tw_link' ) ) ?>" target="_blank"><i
                            class="fa fa-twitter"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_in_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_in_link' ) ) ?>" target="_blank"><i
                            class="fa fa-instagram"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_li_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_li_link' ) ) ?>" target="_blank"><i
                            class="fa fa-linkedin"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_bl_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_bl_link' ) ) ?>" target="_blank"><i
                            class="fa fa-heart"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_pi_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_pi_link' ) ) ?>" target="_blank"><i
                            class="fa fa-pinterest"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_gp_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_gp_link' ) ) ?>" target="_blank"><i
                            class="fa fa-google-plus"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_fs_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_fs_link' ) ) ?>" target="_blank"><i
                            class="fa fa-foursquare"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_fl_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_fl_link' ) ) ?>" target="_blank"><i
                            class="fa fa-flickr"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_dr_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_dr_link' ) ) ?>" target="_blank"><i
                            class="fa fa-dribbble"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_be_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_be_link' ) ) ?>" target="_blank"><i
                            class="fa fa-behance"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_youtube_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_youtube_link' ) ) ?>" target="_blank"><i
                            class="fa fa-youtube"></i></a>
			<?php } ?>
			<?php if ( ot_get_option( 'uni_vk_link' ) ) { ?>
                <a href="<?php echo esc_url( ot_get_option( 'uni_vk_link' ) ) ?>" target="_blank"><i
                            class="fa fa-vk"></i></a>
			<?php } ?>
			<?php
		}
		?>
    </div>
	<?php
}

// Add new image sizes
add_image_size( 'unithumb-contactgallery', 570, 405, true );
add_image_size( 'unithumb-relativepost', 260, 174, true );
add_image_size( 'unithumb-eventpost', 502, 342, true );
add_image_size( 'unithumb-blog', 408, 272, true );
add_image_size( 'unithumb-blogv2', 840, 560, true );
add_image_size( 'unithumb-homepostbig', 960, 960, true );
add_image_size( 'unithumb-homepostsmall', 480, 480, true );
add_image_size( 'unithumb-homeposthalf', 960, 480, true );
add_image_size( 'unithumb-minicartphoto', 52, 52, true );
add_image_size( 'unithumb-cartimage', 128, 128, true );
add_image_size( 'unithumb-attachment', 1170, 0, false );
add_image_size( 'unithumb-aboutussquare', 342, 342, true );

// Register sidebar
add_action( 'widgets_init', 'uni_asana_theme_sidebars_init' );
function uni_asana_theme_sidebars_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'asana' ),
		'id'            => 'sidebar-main',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>',
	) );
}

// add the new role
add_action( 'after_switch_theme', 'uni_asana_theme_activation_func', 10 );
function uni_asana_theme_activation_func() {
	add_role( 'instructor', esc_html__( 'Instructor', 'asana' ), array( 'read' => true ) );
	$instructor = get_role( 'instructor' );
	$instructor->add_cap( 'read' );
	$instructor->add_cap( 'edit_published_posts' );
	$instructor->add_cap( 'upload_files' );
	$instructor->add_cap( 'publish_posts' );
	$instructor->add_cap( 'delete_published_posts' );
	$instructor->add_cap( 'edit_posts' );
	$instructor->add_cap( 'delete_posts' );
	update_option( 'posts_per_page', 9 );
	flush_rewrite_rules();
}

// remove the new role on theme deactivation
add_action( 'switch_theme', 'uni_asana_theme_deactivation_func' );
function uni_asana_theme_deactivation_func() {
	remove_role( 'instructor' );
}

// Posts similar by tags with thumbnails
function uni_asana_theme_similar_posts_by_tags() {

	global $post;
	$oOriginalPost = $post;
	$aTags         = wp_get_post_tags( $post->ID );

	if ( isset( $aTags ) ) {
		$aRelatedTagArray = array();
		foreach ( $aTags as $oTag ) {
			$aRelatedTagArray[] = $oTag->term_id;
		}

		$aRelatedArgs = array(
			'post_type'           => 'post',
			'tag__in'             => $aRelatedTagArray,
			'post__not_in'        => array( $post->ID ),
			'posts_per_page'      => 3,
			'orderby'             => 'rand',
			'ignore_sticky_posts' => 1
		);

		$oRelatedQuery = new wp_query( $aRelatedArgs );
		if ( $oRelatedQuery->have_posts() ) {

			echo '<div class="relatedPostsV2">
                    <h3>' . esc_html__( 'Related Posts', 'asana' ) . '</h3>
                    <div class="relatedPostsWrapV2 clear">';

			while ( $oRelatedQuery->have_posts() ) {
				$oRelatedQuery->the_post();
				?>
                <div class="relatedPostsItemV2">
                    <a href="<?php the_permalink() ?>" class="relatedPostsThumbV2"
                       title="<?php the_title_attribute() ?>">
						<?php if ( has_post_thumbnail() ) { ?>
							<?php the_post_thumbnail( 'unithumb-relativepost', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
						<?php } else { ?>
                            <img src="http://placehold.it/260x174" width="260" height="174"
                                 alt="<?php the_title_attribute() ?>"/>
						<?php } ?>
                    </a>
                    <h4><a href="<?php the_permalink() ?>"
                           title="<?php the_title_attribute() ?>"><?php the_title() ?></a></h4>
					<?php
					$aCategories = wp_get_post_terms( $post->ID, 'category' );
					if ( $aCategories && ! is_wp_error( $aCategories ) ) :
						$s = count( $aCategories );
						$i = 1;
						foreach ( $aCategories as $oTerm ) {
							echo '<a href="' . esc_url( get_term_link( $oTerm->slug, 'category' ) ) . '" class="categoryLink">' . esc_attr( $oTerm->name ) . '</a>';
							if ( $i < $s ) {
								echo ', ';
							}
							$i ++;
						}
					endif;
					?>
                </div>
			<?php }
			echo '</div>
                </div>';
		}
	}
	$post = $oOriginalPost;
	wp_reset_postdata();
}

//
function uni_asana_theme_pre_get_posts( $query ) {
	//global $wp_query;
	if ( ! is_admin() && is_tax( 'uni_event_cat' ) && $query->is_main_query() ) {
		if ( isset( $_GET['events_sort'] ) && $_GET['events_sort'] == 'newer' ) {
			$query->set( 'order', 'DESC' );
			$query->set( 'orderby', 'meta_value' );
			$query->set( 'meta_key', 'uni_event_date' );
			$query->set( 'meta_type', 'DATE' );
		} else if ( isset( $_GET['events_sort'] ) && $_GET['events_sort'] == 'older' ) {
			$query->set( 'order', 'ASC' );
			$query->set( 'orderby', 'meta_value' );
			$query->set( 'meta_key', 'uni_event_date' );
			$query->set( 'meta_type', 'DATE' );
		}
	}
	if ( ! is_admin() && is_tax( 'event_category' ) && $query->is_main_query() ) {
		if ( isset( $_GET['events_sort'] ) && $_GET['events_sort'] == 'newer' ) {
			$query->set( 'order', 'DESC' );
			$query->set( 'orderby', 'meta_value' );
			$query->set( 'meta_key', 'event_date_time' );
			$query->set( 'meta_type', 'DATE' );
		} else if ( isset( $_GET['events_sort'] ) && $_GET['events_sort'] == 'older' ) {
			$query->set( 'order', 'ASC' );
			$query->set( 'orderby', 'meta_value' );
			$query->set( 'meta_key', 'event_date_time' );
			$query->set( 'meta_type', 'DATE' );
		}
	}

	return $query;
}

add_filter( 'pre_get_posts', 'uni_asana_theme_pre_get_posts' );

// Related by tags posts with thumb
function uni_asana_theme_similar_posts_by_tags_v2() {   // uni_asana_theme_relative_posts_by_tags

	global $post;
	$oOriginalPost = $post;
	$aTags         = wp_get_post_tags( $post->ID );

	if ( isset( $aTags ) ) {
		$aRelativeTagArray = array();
		foreach ( $aTags as $oTag ) {
			$aRelativeTagArray[] = $oTag->term_id;
		}

		$aRelatedArgs = array(
			'post_type'           => 'post',
			'tag__in'             => $aRelativeTagArray,
			'post__not_in'        => array( $post->ID ),
			'posts_per_page'      => 3,
			'orderby'             => 'rand',
			'ignore_sticky_posts' => 1
		);

		$oRelatedQuery = new wp_query( $aRelatedArgs );
		if ( $oRelatedQuery->have_posts() ) {

			echo '<div class="relatedPosts">
			    <div class="blockTitle">' . esc_html__( 'Related posts', 'asana' ) . '</div>
			    <div class="blogPostWrap">';

			while ( $oRelatedQuery->have_posts() ) {
				$oRelatedQuery->the_post();
				?>
                <div class="postItem">
                    <a href="<?php the_permalink() ?>" class="postItemImg">
						<?php if ( has_post_thumbnail() ) { ?>
							<?php the_post_thumbnail( 'unithumb-blog', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
						<?php } else { ?>
                            <img src="http://placehold.it/408x272/5FC7AE/FFFFFF" width="408" height="272"
                                 alt="<?php the_title_attribute() ?>"/>
						<?php } ?>
                    </a>
                    <h4><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
					<?php if ( has_excerpt( $post->ID ) ) {
						the_excerpt();
					} else {
						uni_asana_theme_excerpt( 15, '', true );
					} ?>
                </div>
			<?php }
			echo '</div>
				</div>';
		}
	}
	$post = $oOriginalPost;
	wp_reset_postdata();
}

// custom excerpt
function uni_asana_theme_excerpt( $iLength, $iPostId = '', $bEcho = false, $sMore = null ) {
	if ( ! empty( $iPostId ) ) {
		$oPost = get_post( $iPostId );
	} else {
		global $post;
		$oPost = $post;
	}

	if ( null === $sMore ) {
		$sMore = esc_html__( '&hellip;', 'asana' );
	}

	$sContent = $oPost->post_content;
	$sContent = wp_strip_all_tags( $sContent );
	$sContent = strip_shortcodes( $sContent );
	if ( 'characters' == _x( 'words', 'word count: words or characters?', 'asana' ) && preg_match( '/^utf\-?8$/i', get_option( 'blog_charset' ) ) ) {
		$sContent = trim( preg_replace( "/[\n\r\t ]+/", ' ', $sContent ), ' ' );
		preg_match_all( '/./u', $sContent, $aWordsArray );
		$aWordsArray = array_slice( $aWordsArray[0], 0, $iLength + 1 );
		$sep         = '';
	} else {
		$aWordsArray = preg_split( "/[\n\r\t ]+/", $sContent, $iLength + 1, PREG_SPLIT_NO_EMPTY );
		$sep         = ' ';
	}

	if ( count( $aWordsArray ) > $iLength ) {
		array_pop( $aWordsArray );
		$sContent = implode( $sep, $aWordsArray );
		$sContent = $sContent . $sMore;
	} else {
		$sContent = implode( $sep, $aWordsArray );
	}
	if ( $bEcho ) {
		echo '<p>' . $sContent . '</p>';
	} else {
		return $sContent;
	}
}

//
function uni_asana_theme_allowed_html_wo_a() {
	$aAllowedHtml = array(
		'br'     => array(),
		'em'     => array(),
		'span'   => array(
			'class' => array(),
			'style' => array()
		),
		'strong' => array(),
	);

	return $aAllowedHtml;
}

//
function uni_asana_theme_allowed_html_with_a() {
	$aAllowedHtml = array(
		'a'      => array(
			'href'   => array(),
			'title'  => array(),
			'target' => array()
		),
		'br'     => array(),
		'em'     => array(),
		'span'   => array(
			'class' => array(),
			'style' => array()
		),
		'strong' => array(),
	);

	return $aAllowedHtml;
}

function uni_asana_theme_excerpt_more( $more ) {
	return '...';
}

add_filter( 'excerpt_more', 'uni_asana_theme_excerpt_more' );

// comments
function uni_asana_theme_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	global $post;
	?>
    <li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
    <a id="view-comment-<?php comment_ID(); ?>" class="comment-anchor"></a>
    <article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
        <footer class="comment-meta">
            <div class="comment-author vcard">
				<?php if ( 0 != $args['avatar_size'] ) {
					echo get_avatar( $comment, $args['avatar_size'] );
				} ?>
            </div><!-- .comment-author -->

            <div class="reply">
				<?php comment_reply_link( array_merge( $args, array(
					'add_below' => 'div-comment',
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
					'before'    => '<div>',
					'after'     => '</div>'
				) ) ); ?>
            </div><!-- .reply -->
        </footer><!-- .comment-meta -->

        <div class="comment-wrapper">
			<?php
			if ( $comment->user_id === $post->post_author ) {
				printf( '<cite class="fn">%s</cite><span class="uni-post-author">%s</span>', get_comment_author_link(), esc_html__( 'post author', 'asana' ) );
			} else {
				printf( '<cite class="fn">%s</cite>', get_comment_author_link() );
			}
			?>

            <span class="comment-metadata">
				<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
					<time datetime="<?php comment_time( 'c' ); ?>">
						<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'asana' ), get_comment_date(), get_comment_time() ); ?>
					</time>
				</a>
				<?php edit_comment_link( esc_html__( 'Edit', 'asana' ), '<span class="separator">&middot;</span> <span class="edit-link">', '</span>' ); ?>
			</span><!-- .comment-metadata -->

			<?php if ( '0' == $comment->comment_approved ): ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'asana' ); ?></p>
			<?php endif; ?>

            <div class="comment-content">
				<?php comment_text(); ?>
            </div><!-- .comment-content -->
        </div>
    </article><!-- .comment-body -->
	<?php
}

// Ajax contact form - processing
function uni_asana_theme_contact_form() {

	$aResult            = array();
	$aResult['message'] = esc_html__( 'Error!', 'asana' );
	$aResult['status']  = 'error';

	$sCustomerName    = ( ( isset( $_POST['uni_contact_name'] ) ) ? strip_tags( $_POST['uni_contact_name'] ) : '' );
	$sCustomerEmail   = ( ( isset( $_POST['uni_contact_email'] ) ) ? strip_tags( $_POST['uni_contact_email'] ) : '' );
	$sCustomerSubject = ( ( isset( $_POST['uni_contact_subject'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_subject'] ) ) : '' );
	$sCustomerMsg     = ( ( isset( $_POST['uni_contact_msg'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_msg'] ) ) : '' );
	$iPageId          = ( ( isset( $_POST['page_id'] ) ) ? esc_sql( intval( $_POST['page_id'] ) ) : '' );
	$sNonce           = $_POST['uni_contact_nonce'];
	$sAntiCheat       = $_POST['cheaters_always_disable_js'];

	if ( ( empty( $sAntiCheat ) || $sAntiCheat != 'true_bro' ) || ! wp_verify_nonce( $_POST['uni_contact_nonce'], 'uni_nonce' ) ) {
		wp_send_json( $aResult );
	}

	if ( $sCustomerName && $sCustomerEmail && $sCustomerSubject && $sCustomerMsg ) {

		if ( ! empty( $iPageId ) ) {
			$aPostCustom = get_post_custom( $iPageId );
			if ( ! empty( $aPostCustom['uni_contact_email'][0] ) ) {
				$sToEmail = sanitize_email( $aPostCustom['uni_contact_email'][0] );
			} else if ( ot_get_option( 'uni_email' ) && empty( $aPostCustom['uni_contact_email'][0] ) ) {
				$sToEmail = sanitize_email( ot_get_option( 'uni_email' ) );
			} else {
				$sToEmail = esc_attr( get_bloginfo( 'admin_email' ) );
			}
		} else {
			$sToEmail = ( ot_get_option( 'uni_email' ) ) ? ot_get_option( 'uni_email' ) : get_bloginfo( 'admin_email' );
		}

		if ( ot_get_option( 'uni_use_visitor_email_from' ) !== 'off' ) {
			$aHeadersText[] = "From: $sCustomerName <$sCustomerEmail>";
		} else {
			$sFromEmail     = sanitize_email( ot_get_option( 'uni_custom_email_from' ) );
			$aHeadersText[] = "From: $sCustomerName <$sFromEmail>";
			$aHeadersText[] = "Sender: $sFromEmail";
			$aHeadersText[] = "Reply-To: $sCustomerName <$sCustomerEmail>";
		}

		$sSubjectText = html_entity_decode( $sCustomerSubject );

		$sBlogName = get_bloginfo( 'name' );

		$sMessage =
			"<h3>" . sprintf( esc_html__( 'You have a new message sent from "%s"!', 'asana' ), $sBlogName ) . "</h3>
                    <p></p>
                    <p><strong>" . esc_html__( 'Contact information', 'asana' ) . ":</strong><br>
                    " . sprintf( esc_html__( 'Name: %s', 'asana' ), $sCustomerName ) . "
                    <br>
                    " . sprintf( esc_html__( 'Email: %s', 'asana' ), $sCustomerEmail ) . "
                    <br>
                    " . esc_html__( 'Message', 'asana' ) . ":
                    <br>$sCustomerMsg
                    </p>";
		$sMessage = stripslashes( $sMessage );

		uni_asana_theme_send_email_wrapper( $sToEmail, $aHeadersText, $sSubjectText, false, array(), $sMessage );

		$aResult['status']  = 'success';
		$aResult['message'] = esc_html__( 'Thanks! Your message has been sent!', 'asana' );

	} else {
		$aResult['message'] = esc_html__( 'All fields are required!', 'asana' );
	}

	wp_send_json( $aResult );
}

add_action( 'wp_ajax_uni_asana_theme_contact_form', 'uni_asana_theme_contact_form' );
add_action( 'wp_ajax_nopriv_uni_asana_theme_contact_form', 'uni_asana_theme_contact_form' );

// join event form - processing
function uni_asana_theme_join_event_form() {

	$aResult            = array();
	$aResult['message'] = esc_html__( 'Error!', 'asana' );
	$aResult['status']  = 'error';

	$sDateFormat = get_option( 'date_format' );
	$sTimeFormat = get_option( 'time_format' );

	$sCustomerFName = ( ! empty( $_POST['uni_contact_firstname'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_firstname'] ) ) : '';
	$sCustomerLName = ( ! empty( $_POST['uni_contact_lastname'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_lastname'] ) ) : '';
	$sCustomerEmail = ( ! empty( $_POST['uni_contact_email'] ) ) ? strip_tags( $_POST['uni_contact_email'] ) : '';
	$sCustomerPhone = ( ! empty( $_POST['uni_contact_phone'] ) ) ? strip_tags( $_POST['uni_contact_phone'] ) : '';
	$sCustomerMsg   = ( ! empty( $_POST['uni_contact_msg'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_msg'] ) ) : '';
	$iEventId       = absint( esc_sql( $_POST['event_id'] ) );
	$sNonce         = $_POST['uni_contact_nonce'];
	$sAntiCheat     = $_POST['cheaters_always_disable_js'];

	if ( ( empty( $sAntiCheat ) || $sAntiCheat != 'true_bro' ) || ! wp_verify_nonce( $_POST['uni_contact_nonce'], 'uni_nonce' ) ) {
		wp_send_json( $aResult );
	}

	if ( $sCustomerFName && $sCustomerLName && $sCustomerEmail && $sCustomerPhone && $sCustomerMsg ) {

		$sAdminEmail = ( ot_get_option( 'uni_email' ) ) ? ot_get_option( 'uni_email' ) : get_bloginfo( 'admin_email' );
		$sEventTitle = get_the_title( $iEventId );
		$aCustomData = get_post_custom( $iEventId );

		if ( ! empty( $aCustomData['uni_event_date_start'][0] ) && ! empty( $aCustomData['uni_event_date_end'][0] ) &&
		     $aCustomData['uni_event_date_start'][0] === $aCustomData['uni_event_date_end'][0] ) {
			$iDateStartTimestamp = strtotime( $aCustomData['uni_event_date_start'][0] );
			$sEventDate          = date_i18n( $sDateFormat, $iDateStartTimestamp );
		} else if ( ! empty( $aCustomData['uni_event_date_start'][0] ) && ! empty( $aCustomData['uni_event_date_end'][0] ) &&
		            $aCustomData['uni_event_date_start'][0] !== $aCustomData['uni_event_date_end'][0] ) {
			$iDateStartTimestamp = strtotime( $aCustomData['uni_event_date_start'][0] );
			$iDateEndTimestamp   = strtotime( $aCustomData['uni_event_date_end'][0] );
			$sEventDate          = date_i18n( $sDateFormat, $iDateStartTimestamp ) . ' - ' . date_i18n( $sDateFormat, $iDateEndTimestamp );
		} else if ( ! empty( $aCustomData['uni_event_date_start'][0] ) && empty( $aCustomData['uni_event_date_end'][0] ) ) {
			$iDateStartTimestamp = strtotime( $aCustomData['uni_event_date_start'][0] );
			$sEventDate          = date_i18n( $sDateFormat, $iDateStartTimestamp );
		} else {
			$sEventDate = esc_html__( '- not specified -', 'asana' );
		}

		if ( ! empty( $aCustomData['uni_event_time_start'][0] ) && ! empty( $aCustomData['uni_event_time_end'][0] ) &&
		     $aCustomData['uni_event_time_start'][0] === $aCustomData['uni_event_time_end'][0] ) {
			$iTimeStartTimestamp = strtotime( $aCustomData['uni_event_time_start'][0] );
			$sEventTime          = date_i18n( $sTimeFormat, $iTimeStartTimestamp );
		} else if ( ! empty( $aCustomData['uni_event_time_start'][0] ) && ! empty( $aCustomData['uni_event_time_end'][0] ) &&
		            $aCustomData['uni_event_time_start'][0] !== $aCustomData['uni_event_time_end'][0] ) {
			$iTimeStartTimestamp = strtotime( $aCustomData['uni_event_time_start'][0] );
			$iTimeEndTimestamp   = strtotime( $aCustomData['uni_event_time_end'][0] );
			$sEventTime          = date_i18n( $sTimeFormat, $iTimeStartTimestamp ) . ' - ' . date_i18n( $sTimeFormat, $iTimeEndTimestamp );
		} else if ( ! empty( $aCustomData['uni_event_time_start'][0] ) && empty( $aCustomData['uni_event_time_end'][0] ) ) {
			$iTimeStartTimestamp = strtotime( $aCustomData['uni_event_time_start'][0] );
			$sEventTime          = date_i18n( $sTimeFormat, $iTimeStartTimestamp );
		} else {
			$sEventTime = esc_html__( '- not specified -', 'asana' );
		}

		$sEventLocation = ( ! empty( $aCustomData['uni_event_address'][0] ) ) ? esc_html( $aCustomData['uni_event_address'][0] ) : esc_html__( '- not specified -', 'asana' );
		$sEventPrice    = ( ! empty( $aCustomData['uni_event_price'][0] ) ) ? esc_html( $aCustomData['uni_event_price'][0] ) : esc_html__( '- not specified -', 'asana' );
		$sPhone         = ( ot_get_option( 'uni_phone' ) ) ? esc_html( ot_get_option( 'uni_phone' ) ) : '+88 (0) 101 0000 000';
		$sEmail         = ( ot_get_option( 'uni_email' ) ) ? esc_html( ot_get_option( 'uni_email' ) ) : esc_html( get_bloginfo( 'admin_email' ) );

		// send an email to the client
		$sBlogName = get_bloginfo( 'name' );
		if ( ot_get_option( 'uni_use_visitor_email_from' ) !== 'off' ) {
			$aHeadersText[] = "From: " . esc_attr( $sBlogName ) . " <$sAdminEmail>";
		} else {
			$sFromEmail     = sanitize_email( ot_get_option( 'uni_custom_email_from' ) );
			$aHeadersText[] = "From: " . esc_attr( $sBlogName ) . " <$sFromEmail>";
			$aHeadersText[] = "Sender: $sFromEmail";
			$aHeadersText[] = "Reply-To: " . esc_attr( $sBlogName ) . " <$sAdminEmail>";
		}

		$sSubjectText       = html_entity_decode( sprintf( esc_html__( 'Successful registration for %s', 'asana' ), $sEventTitle ), ENT_COMPAT, 'UTF-8' );
		$sEmailTemplateName = apply_filters( 'uni_asana_event_email_filter', '/email/event-guest.php', 'guest' );
		$aMailVars          = array(
			'$sEventTitle'    => '"' . $sEventTitle . '"',
			'$sEventDate'     => $sEventDate,
			'$sEventTime'     => $sEventTime,
			'$sEventLocation' => $sEventLocation,
			'$sEventPrice'    => $sEventPrice,
			'$sPhone'         => $sPhone,
			'$sEmail'         => $sEmail
		);

		uni_asana_theme_send_email_wrapper( $sCustomerEmail, $aHeadersText, $sSubjectText, $sEmailTemplateName, $aMailVars, '' );

		// send an email to the admin
		if ( ot_get_option( 'uni_use_visitor_email_from' ) !== 'off' ) {
			$aHeadersText[] = "From: $sCustomerFName $sCustomerLName <$sCustomerEmail>";
		} else {
			$sFromEmail     = sanitize_email( ot_get_option( 'uni_custom_email_from' ) );
			$aHeadersText[] = "From: $sCustomerFName $sCustomerLName <$sFromEmail>";
			$aHeadersText[] = "Sender: $sFromEmail";
			$aHeadersText[] = "Reply-To: $sCustomerFName $sCustomerLName <$sCustomerEmail>";
		}
		$sSubjectText       = html_entity_decode( sprintf( esc_html__( 'A new registration for %s', 'asana' ), $sEventTitle ), ENT_COMPAT, 'UTF-8' );
		$sClientName        = $sCustomerFName . ' ' . $sCustomerLName;
		$sClientTel         = $sCustomerPhone;
		$sClientEmail       = $sCustomerEmail;
		$sClientMsg         = $sCustomerMsg;
		$sEmailTemplateName = apply_filters( 'uni_asana_event_email_filter', '/email/event-admin.php', 'admin' );
		$aMailVars          = array(
			'$sEventTitle'  => '"' . $sEventTitle . '"',
			'$sEventDate'   => $sEventDate,
			'$sClientName'  => $sClientName,
			'$sClientTel'   => $sClientTel,
			'$sClientEmail' => $sClientEmail,
			'$sClientMsg'   => $sClientMsg
		);

		uni_asana_theme_send_email_wrapper( $sAdminEmail, $aHeadersText, $sSubjectText, $sEmailTemplateName, $aMailVars, '' );

		$aResult['status']  = 'success';
		$aResult['message'] = esc_html__( 'Thanks! You have successfully registered!', 'asana' );

	} else {
		$aResult['message'] = esc_html__( 'All fields are required!', 'asana' );
	}

	wp_send_json( $aResult );
}

add_action( 'wp_ajax_uni_asana_theme_join_event_form', 'uni_asana_theme_join_event_form' );
add_action( 'wp_ajax_nopriv_uni_asana_theme_join_event_form', 'uni_asana_theme_join_event_form' );

// price form - processing
function uni_asana_theme_price_form() {

	$aResult            = array();
	$aResult['message'] = esc_html__( 'Error!', 'asana' );
	$aResult['status']  = 'error';

	$sCustomerFName = ( ! empty( $_POST['uni_contact_firstname'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_firstname'] ) ) : '';
	$sCustomerLName = ( ! empty( $_POST['uni_contact_lastname'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_lastname'] ) ) : '';
	$sCustomerEmail = ( ! empty( $_POST['uni_contact_email'] ) ) ? strip_tags( $_POST['uni_contact_email'] ) : '';
	$sCustomerPhone = ( ! empty( $_POST['uni_contact_phone'] ) ) ? strip_tags( $_POST['uni_contact_phone'] ) : '';
	$sCustomerMsg   = ( ! empty( $_POST['uni_contact_msg'] ) ) ? stripslashes( strip_tags( $_POST['uni_contact_msg'] ) ) : '';
	$iPriceId       = absint( esc_sql( $_POST['uni_price_id'] ) );
	$sNonce         = $_POST['uni_contact_nonce'];
	$sAntiCheat     = $_POST['cheaters_always_disable_js'];

	if ( ( empty( $sAntiCheat ) || $sAntiCheat != 'true_bro' ) || ! wp_verify_nonce( $_POST['uni_contact_nonce'], 'uni_nonce' ) ) {
		wp_send_json( $aResult );
	}

	if ( $sCustomerFName && $sCustomerLName && $sCustomerEmail && $sCustomerPhone && $sCustomerMsg ) {

		$sAdminEmail    = ( ot_get_option( 'uni_email' ) ) ? ot_get_option( 'uni_email' ) : get_bloginfo( 'admin_email' );
		$sPriceTitle    = get_the_title( $iPriceId );
		$aCustomData    = get_post_custom( $iPriceId );
		$sPriceCurrency = ( ! empty( $aCustomData['uni_currency'][0] ) ) ? esc_html( $aCustomData['uni_currency'][0] ) : esc_html__( '- not specified -', 'asana' );
		$sPriceVal      = ( ! empty( $aCustomData['uni_price_val'][0] ) ) ? esc_html( $aCustomData['uni_price_val'][0] ) : esc_html__( '- not specified -', 'asana' );
		$sPricePeriod   = ( ! empty( $aCustomData['uni_period'][0] ) ) ? esc_html( $aCustomData['uni_period'][0] ) : esc_html__( '- not specified -', 'asana' );
		$sPhone         = ( ot_get_option( 'uni_phone' ) ) ? esc_html( ot_get_option( 'uni_phone' ) ) : '+88 (0) 101 0000 000';
		$sEmail         = ( ot_get_option( 'uni_email' ) ) ? esc_html( ot_get_option( 'uni_email' ) ) : esc_html( get_bloginfo( 'admin_email' ) );

		// send an email to the client
		$sBlogName = get_bloginfo( 'name' );
		if ( ot_get_option( 'uni_use_visitor_email_from' ) !== 'off' ) {
			$aHeadersText[] = "From: " . esc_attr( $sBlogName ) . " <$sAdminEmail>";
		} else {
			$sFromEmail     = sanitize_email( ot_get_option( 'uni_custom_email_from' ) );
			$aHeadersText[] = "From: " . esc_attr( $sBlogName ) . " <$sFromEmail>";
			$aHeadersText[] = "Sender: $sFromEmail";
			$aHeadersText[] = "Reply-To: " . esc_attr( $sBlogName ) . " <$sAdminEmail>";
		}
		$sSubjectText       = html_entity_decode( sprintf( esc_html__( 'Successful request for %s', 'asana' ), $sPriceTitle ), ENT_COMPAT, 'UTF-8' );
		$sEmailTemplateName = apply_filters( 'uni_asana_price_email_filter', '/email/price-guest.php', 'guest' );
		$aMailVars          = array(
			'$sPriceTitle'    => '"' . $sPriceTitle . '"',
			'$sPriceCurrency' => $sPriceCurrency,
			'$sPriceVal'      => $sPriceVal,
			'$sPricePeriod'   => $sPricePeriod,
			'$sPhone'         => $sPhone,
			'$sEmail'         => $sEmail
		);

		uni_asana_theme_send_email_wrapper( $sCustomerEmail, $aHeadersText, $sSubjectText, $sEmailTemplateName, $aMailVars, '' );

		// send an email to the admin
		if ( ot_get_option( 'uni_use_visitor_email_from' ) !== 'off' ) {
			$aHeadersText[] = "From: $sCustomerFName $sCustomerLName <$sCustomerEmail>";
		} else {
			$sFromEmail     = sanitize_email( ot_get_option( 'uni_custom_email_from' ) );
			$aHeadersText[] = "From: $sCustomerFName $sCustomerLName <$sFromEmail>";
			$aHeadersText[] = "Sender: $sFromEmail";
			$aHeadersText[] = "Reply-To: $sCustomerFName $sCustomerLName <$sCustomerEmail>";
		}
		$sSubjectText       = html_entity_decode( sprintf( esc_html__( 'A new request for %s', 'asana' ), $sPriceTitle ), ENT_COMPAT, 'UTF-8' );
		$sClientName        = $sCustomerFName . ' ' . $sCustomerLName;
		$sClientTel         = $sCustomerPhone;
		$sClientEmail       = $sCustomerEmail;
		$sClientMsg         = $sCustomerMsg;
		$sEmailTemplateName = apply_filters( 'uni_asana_price_email_filter', '/email/price-admin.php', 'admin' );
		$aMailVars          = array(
			'$sPriceTitle'  => '"' . $sPriceTitle . '"',
			'$sPricePeriod' => $sPricePeriod,
			'$sClientName'  => $sClientName,
			'$sClientTel'   => $sClientTel,
			'$sClientEmail' => $sClientEmail,
			'$sClientMsg'   => $sClientMsg
		);

		uni_asana_theme_send_email_wrapper( $sAdminEmail, $aHeadersText, $sSubjectText, $sEmailTemplateName, $aMailVars, '' );

		$aResult['status']  = 'success';
		$aResult['message'] = esc_html__( 'Thanks! Your request was successfully sent!', 'asana' );

	} else {
		$aResult['message'] = esc_html__( 'All fields are required!', 'asana' );
	}

	wp_send_json( $aResult );
}

add_action( 'wp_ajax_uni_asana_theme_price_form', 'uni_asana_theme_price_form' );
add_action( 'wp_ajax_nopriv_uni_asana_theme_price_form', 'uni_asana_theme_price_form' );

// mailchimp subscribe user
function uni_asana_theme_mailchimp_subscribe_user() {

	$aResult            = array();
	$aResult['message'] = esc_html__( 'Error!', 'asana' );
	$aResult['status']  = 'error';

	$sEmail     = $_POST['uni_input_email'];
	$sAntiCheat = $_POST['cheaters_always_disable_js'];

	if ( empty( $sAntiCheat ) || $sAntiCheat != 'true_bro' ) {
		wp_send_json( $aResult );
	}

	$sApiKey = ot_get_option( 'uni_mailchimp_api_key' );
	$sListId = ot_get_option( 'uni_mailchimp_list_id' );

	if ( ! empty( $sApiKey ) && ! empty( $sListId ) ) {

		$oUniMailchimp = Uni_Mailchimp_Universal( $sApiKey, $sListId );
		$aListOfMCVars = apply_filters( 'uni_asana_theme_mailchimp_variables_filter', array(
			'email_address' => $sEmail,
			'status'        => 'pending'
		) );
		$aResponse     = $oUniMailchimp->call_lists_members( 'lists/members', 'POST', $aListOfMCVars );

		if ( $aResponse['status'] == 'success' ) {
			$aResult['message'] = esc_html__( 'Success!', 'asana' );
			$aResult['status']  = 'success';
		} else {
			$aResult['message'] = ( isset( $aResponse['response']->detail ) && ! empty( $aResponse['response']->detail ) ) ? $aResponse['response']->detail : $aResponse['message'];
		}

	} else {
		$aResult['message'] = esc_html__( 'No API key and/or List ID is/are specified!', 'asana' );
	}

	wp_send_json( $aResult );
}

add_action( 'wp_ajax_uni_asana_theme_mailchimp_subscribe_user', 'uni_asana_theme_mailchimp_subscribe_user' );
add_action( 'wp_ajax_nopriv_uni_asana_theme_mailchimp_subscribe_user', 'uni_asana_theme_mailchimp_subscribe_user' );

// body classes
function uni_asana_theme_body_classes( $classes ) {
	if ( class_exists( 'Woocommerce' ) ) {
		if ( is_cart() || is_checkout() ) {
			foreach ( $classes as $sKey => $sClass ) {
				if ( $sClass == 'page-template-default' ) {
					unset( $classes[ $sKey ] );
				}
			}
		}
	}
	if ( ot_get_option( 'uni_nav_white_enable' ) && ot_get_option( 'uni_nav_white_enable' ) == 'on' ) {
		$classes[] = 'fixedMainMenu';
	}
	if ( ( ( is_home() || is_front_page() ) && ( ot_get_option( 'uni_home_rev_slider_enable' ) && ot_get_option( 'uni_home_rev_slider_enable' ) == 'off' && ot_get_option( 'uni_home_slider_enable' ) && ot_get_option( 'uni_home_slider_enable' ) == 'off' ) )
	     || ( ( is_home() || is_front_page() ) && ! ot_get_option( 'uni_home_rev_slider_enable' ) && ! ot_get_option( 'uni_home_slider_enable' ) ) ) {
		$classes[] = 'home-slider-disabled';
	}

	return $classes;
}

add_filter( 'body_class', 'uni_asana_theme_body_classes' );


//*********** WooCommerce ****************************************************************
// archive-product.php
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );

add_action( 'woocommerce_before_main_content', 'uni_asana_theme_woo_output_content_wrapper', 10 );
add_action( 'woocommerce_before_main_content', 'uni_asana_theme_page_panel_output', 15 );
add_action( 'woocommerce_after_main_content', 'uni_asana_theme_woo_output_content_wrapper_end', 10 );
add_action( 'woocommerce_before_main_content', 'uni_asana_theme_minicart_content', 20 );

function uni_asana_theme_woo_output_content_wrapper() {
	// if this is single product page
	if ( is_singular( 'product' ) ) {
		$iShopAttachId = ( ot_get_option( 'uni_shop_header_bg' ) ) ? ot_get_option( 'uni_shop_header_bg' ) : '';
		$sTitleColor   = ( ot_get_option( 'uni_shop_header_title_color' ) ) ? ot_get_option( 'uni_shop_header_title_color' ) : '#ffffff';
		if ( ! empty( $iShopAttachId ) ) {
			$aPageHeaderImage = wp_get_attachment_image_src( $iShopAttachId, 'full' );
			$sPageHeaderImage = $aPageHeaderImage[0];
		} else {
			$sPageHeaderImage = get_template_directory_uri() . '/images/placeholders/pageheader-shop.jpg';
		}
		$sOutput = '<section class="uni-container">
		    <div class="pageHeader" style="background-image: url(' . esc_url( $sPageHeaderImage ) . ');">';
		if ( ot_get_option( 'uni_shop_header_title' ) ) {
			$sOutput .= '<div>' . esc_html( ot_get_option( 'uni_shop_header_title' ) ) . '</div>';
		} else {
			$sOutput .= '<div>' . esc_html__( 'ONLINE BOUTIQUE', 'asana' ) . '</div>';
		}
		$sOutput .= '</div>';
		$sOutput .= '<style>.pageHeader h1 {color:' . $sTitleColor . ';}</style>';
		$sOutput .= '<div class="contentWrap">';
		// other pages
	} else {
		$iShopAttachId = ( ot_get_option( 'uni_shop_header_bg' ) ) ? ot_get_option( 'uni_shop_header_bg' ) : '';
		$sTitleColor   = ( ot_get_option( 'uni_shop_header_title_color' ) ) ? ot_get_option( 'uni_shop_header_title_color' ) : '#ffffff';
		if ( ! empty( $iShopAttachId ) ) {
			$aPageHeaderImage = wp_get_attachment_image_src( $iShopAttachId, 'full' );
			$sPageHeaderImage = $aPageHeaderImage[0];
		} else {
			$sPageHeaderImage = get_template_directory_uri() . '/images/placeholders/pageheader-shop.jpg';
		}
		$sOutput = '<section class="uni-container">
		    <div class="pageHeader" style="background-image: url(' . esc_url( $sPageHeaderImage ) . ');">';
		if ( is_shop() ) {
			if ( ot_get_option( 'uni_shop_header_title' ) ) {
				$sOutput .= '<h1>' . esc_html( ot_get_option( 'uni_shop_header_title' ) ) . '</h1>';
			} else {
				$sOutput .= '<h1>' . esc_html__( 'ONLINE BOUTIQUE', 'asana' ) . '</h1>';
			}
		} else {
			$sOutput .= '<h1 class="page-title">' . woocommerce_page_title( false ) . '</h1>';
		}
		$sOutput .= '</div>';
		$sOutput .= '<style>.pageHeader h1 {color:' . $sTitleColor . ';}</style>';
		$sOutput .= '<div class="contentWrap">';
	}

	echo $sOutput;
}

function uni_asana_theme_woo_output_content_wrapper_end() {
	echo '<div class="overlay"></div>
		</div>
	</section>';
}

function uni_asana_theme_page_panel_output() {

	$sOutput = '<div class="pagePanel clear">';

	$sOutput .= uni_asana_theme_product_categories_submenu();

	$sOutput .= uni_asana_theme_woocommerce_minicart_output();

	$sOutput .= '</div>';

	echo $sOutput;
}

function uni_asana_theme_product_categories_submenu() {

	if ( is_singular( 'product' ) ) {
		global $post;
		$aCatsAttached          = wp_get_post_terms( $post->ID, 'product_cat' );
		$aCatsAttachedFormatted = array();
		if ( ! empty( $aCatsAttached ) ) {
			foreach ( $aCatsAttached as $oCat ) {
				$aCatsAttachedFormatted[] = $oCat->slug;
			}
		}

		$sOutput = '<ul class="productFilter clear">';
		$sOutput .= '<li><a href="' . get_permalink( wc_get_page_id( 'shop' ) ) . '">' . esc_html__( 'All', 'asana' ) . '</a></li>';

		$aProdCatsToBeExcluded = ( ot_get_option( 'uni_prod_tax_exclude' ) ) ? ot_get_option( 'uni_prod_tax_eclude' ) : array();
		$aAllParentCats        = get_terms( 'product_cat', array(
			'hide_empty' => false,
			'parent'     => 0,
			'exclude'    => $aProdCatsToBeExcluded
		) );
		if ( isset( $aAllParentCats ) ) {
			foreach ( $aAllParentCats as $oParentCat ) {

				$sOutput .= '<li><a' . ( ( in_array( $oParentCat->slug, $aCatsAttachedFormatted ) ) ? ' class="active"' : '' ) . ' href="' . get_term_link( $oParentCat ) . '">' . esc_html( $oParentCat->name ) . '</a></li>';
			}
		}
		$sOutput .= '</ul>';

	} else {
		$sProdCatSlug = get_query_var( 'product_cat', null );

		$sOutput = '<ul class="productFilter clear">';
		$sOutput .= '<li><a' . ( ( $sProdCatSlug == null ) ? ' class="active"' : '' ) . ' href="' . get_permalink( wc_get_page_id( 'shop' ) ) . '">' . esc_html__( 'All', 'asana' ) . '</a></li>';

		$aProdCatsToBeExcluded = ( ot_get_option( 'uni_prod_tax_exclude' ) ) ? ot_get_option( 'uni_prod_tax_eclude' ) : array();
		$aAllParentCats        = get_terms( 'product_cat', array(
			'hide_empty' => false,
			'parent'     => 0,
			'exclude'    => $aProdCatsToBeExcluded
		) );
		if ( isset( $aAllParentCats ) ) {
			foreach ( $aAllParentCats as $oParentCat ) {

				$sOutput .= '<li><a' . ( ( $sProdCatSlug == $oParentCat->slug ) ? ' class="active"' : '' ) . ' href="' . get_term_link( $oParentCat ) . '">' . esc_html( $oParentCat->name ) . '</a></li>';
			}
		}
		$sOutput .= '</ul>';

	}

	return $sOutput;

}

function uni_asana_theme_woocommerce_minicart_output() {

	if ( class_exists( 'WooCommerce' ) ) {

		global $woocommerce;
		$sOutput = '<div class="miniCart">';
		$sOutput .= '<i></i>';
		if ( sizeof( $woocommerce->cart->get_cart() ) > 0 ) :
			$sOutput .= '<span>' . sizeof( $woocommerce->cart->get_cart() ) . '</span>';
		else :
			$sOutput .= '<span>0</span>';
		endif;
		$sOutput .= '</div>';

		return $sOutput;

	}

}


// content-single-product.php
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50 );

add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 5 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 15 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
add_action( 'woocommerce_single_product_summary', 'uni_asana_theme_template_single_sharing', 50 );


// content-product.php
remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
add_action( 'woocommerce_before_shop_loop_item', 'uni_asana_theme_woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
add_action( 'woocommerce_shop_loop_item_title', 'uni_asana_theme_woocommerce_template_loop_product_title', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
add_action( 'woocommerce_after_shop_loop_item', 'uni_asana_theme_woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );

//
function uni_asana_theme_woocommerce_template_loop_product_link_open() {
	echo '<a href="' . get_the_permalink() . '" class="woocommerce-LoopProduct-link shopItem">';
}

//
function uni_asana_theme_woocommerce_template_loop_product_title() {
	global $product;
	echo '<div class="overlay">';
	echo '<div class="shopItemTextWrap">';
	echo '<h3>' . get_the_title() . '</h3>';
	echo '</div>';
	echo '<span class="price">' . $product->get_price_html() . '</span>';
}

//
function uni_asana_theme_woocommerce_template_loop_product_link_close() {
	echo '</div>';
	echo '</a>';
}

// content-product_cat.php
remove_action( 'woocommerce_before_subcategory', 'woocommerce_template_loop_category_link_open', 10 );
add_action( 'woocommerce_before_subcategory', 'uni_asana_theme_woocommerce_template_loop_category_link_open', 10, 1 );
remove_action( 'woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10 );
add_action( 'woocommerce_shop_loop_subcategory_title', 'uni_asana_theme_woocommerce_template_loop_category_title', 10, 1 );
remove_action( 'woocommerce_after_subcategory', 'woocommerce_template_loop_category_link_close', 10 );
add_action( 'woocommerce_after_subcategory', 'uni_asana_theme_woocommerce_template_loop_product_link_close', 10 );

//
function uni_asana_theme_woocommerce_template_loop_category_link_open( $category ) {
	echo '<a href="' . get_term_link( $category, 'product_cat' ) . '" class="woocommerce-LoopProduct-link shopItem">';
}

//
function uni_asana_theme_woocommerce_template_loop_category_title( $category ) {
	global $product;
	echo '<div class="overlay">';
	echo '<div class="shopItemTextWrap">';
	echo '<h3>';
	echo $category->name;
	if ( $category->count > 0 ) {
		echo apply_filters( 'woocommerce_subcategory_count_html', ' <mark class="count">(' . $category->count . ')</mark>', $category );
	}
	echo '</h3>';
	echo '</div>';
}

// Display 12 products per page.
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 );

add_filter( 'woocommerce_currency_symbol', 'uni_asana_theme_currency_symbol_markup', 2, 10 );
function uni_asana_theme_currency_symbol_markup( $sCurrencySymbol, $currency ) {
	return '<span>' . $sCurrencySymbol . '</span>';
}

//social share buttons on single product page
function uni_asana_theme_template_single_sharing() {
	?>
    <div class="shareSingleProduct">
		<?php if ( ot_get_option( 'uni_fb_share_link_enable' ) != 'off' ) { ?>
            <a href="<?php echo uni_asana_theme_share_facebook(); ?>"><i class="fa fa-facebook"></i></a>
		<?php } ?>
		<?php if ( ot_get_option( 'uni_twi_share_link_enable' ) != 'off' ) { ?>
            <a href="<?php echo uni_asana_theme_share_twitter(); ?>"><i class="fa fa-twitter"></i></a>
		<?php } ?>
		<?php if ( ot_get_option( 'uni_gplus_share_link_enable' ) != 'off' ) { ?>
            <a href="<?php echo uni_asana_theme_share_gplus(); ?>"><i class="fa fa-google-plus"></i></a>
		<?php } ?>
		<?php if ( ot_get_option( 'uni_pi_share_link_enable' ) != 'off' ) { ?>
            <a href="<?php echo uni_asana_theme_share_pinterest(); ?>"><i class="fa fa-pinterest"></i></a>
		<?php } ?>
    </div>
	<?php
}

//
function uni_asana_theme_woo_get_formatted_price( $sPrice ) {

	$num_decimals    = absint( get_option( 'woocommerce_price_num_decimals' ) );
	$currency        = isset( $args['currency'] ) ? $args['currency'] : '';
	$currency_symbol = get_woocommerce_currency_symbol( $currency );
	$decimal_sep     = wp_specialchars_decode( stripslashes( get_option( 'woocommerce_price_decimal_sep' ) ), ENT_QUOTES );
	$thousands_sep   = wp_specialchars_decode( stripslashes( get_option( 'woocommerce_price_thousand_sep' ) ), ENT_QUOTES );

	$price = apply_filters( 'raw_woocommerce_price', floatval( $sPrice ) );
	$price = apply_filters( 'formatted_woocommerce_price', number_format( $price, $num_decimals, $decimal_sep, $thousands_sep ), $price, $num_decimals, $decimal_sep, $thousands_sep );

	return sprintf( get_woocommerce_price_format(), $currency_symbol, $price );
}

//
function uni_asana_theme_woo_get_product_thumbnail( $size = 'shop_catalog', $placeholder_width = 0, $placeholder_height = 0, $iPostId ) {
	if ( has_post_thumbnail( $iPostId ) ) {
		return get_the_post_thumbnail( $iPostId, $size );
	} elseif ( wc_placeholder_img_src() ) {
		return uni_asana_theme_woo_placeholder_img( $placeholder_width, $placeholder_height );
	}
}

//
function uni_asana_theme_woo_placeholder_img( $sWidth = 100, $sHeight = 100 ) {
	return '<img src="' . wc_placeholder_img_src() . '" alt="' . esc_html__( 'Placeholder', 'woocommerce' ) . '" width="' . esc_attr( $sWidth ) . '" class="woocommerce-placeholder wp-post-image" height="' . esc_attr( $sHeight ) . '" />';
}

function uni_asana_theme_minicart_content() {
	global $woocommerce;

	?>
    <div class="miniCartPopup">
        <div class="miniCartPopupHead">
            <h3><?php esc_html_e( 'YOUR CART', 'asana' ); ?></h3>
            <span class="closeCartPopup"></span>
        </div>

        <div class="miniCartItemWrap">
			<?php if ( sizeof( $woocommerce->cart->get_cart() ) > 0 ) : ?>
				<?php
				foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
					$_product      = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
					$product_id    = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
					$product_name  = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key );
					$thumbnail     = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
					$product_price = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
					?>
                    <div class="miniCartItem"
                         data-product_id="<?php echo $product_id ?>"<?php if ( ! empty( $cart_item['_uni_cpo_cart_item_id'] ) ) { ?> data-cart_item_id="<?php echo esc_attr( $cart_item['_uni_cpo_cart_item_id'] ) ?>"<?php } ?>>
                        <a href="<?php echo esc_url( $_product->get_permalink( $cart_item ) ); ?>"
                           class="miniCartItemImg">
							<?php echo uni_asana_theme_woo_get_product_thumbnail( 'unithumb-minicartphoto', 52, 52, $product_id ) ?>
                        </a>
                        <h3>
                            <a href="<?php echo esc_url( $_product->get_permalink( $cart_item ) ); ?>"><?php echo $product_name; ?></a>
                        </h3>
                        <p class="price"><?php echo $product_price; ?></p>
                        <div class="quantity clear">
                            <span><?php esc_html_e( 'Quantity:', 'asana' ); ?></span>
							<?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s', $cart_item['quantity'] ) . '</span>', $cart_item, $cart_item_key ); ?>
                        </div>
						<?php echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf( '<a href="%s" class="remove removeMiniCartItem" title="%s"></a>', esc_url( WC()->cart->get_remove_url( $cart_item_key ) ), esc_html__( 'Remove this item', 'asana' ) ), $cart_item_key ); ?>
						<?php echo WC()->cart->get_item_data( $cart_item ); ?>
                    </div>
				<?php } ?>
                <div class="miniCartSubTotal">
					<?php esc_html_e( 'Subtotal', 'asana' ); ?>
                    <span><?php echo WC()->cart->get_cart_subtotal(); ?></span>
                </div>
                <a href="<?php echo esc_url( wc_get_cart_url() ); ?>"
                   class="btnViewCart"><?php esc_html_e( 'view cart', 'asana' ); ?></a>
                <a href="<?php echo esc_url( wc_get_checkout_url() ); ?>"
                   class="btnCheckout"><?php esc_html_e( 'checkout', 'asana' ); ?></a>

			<?php else: ?>
                <div class="miniCartEmpty">
                    <i></i>
                    <p><?php esc_html_e( 'Your cart is empty', 'asana' ); ?></p>
                </div>
			<?php endif; ?>
        </div>
    </div>
	<?php
}

// wishlist filters
add_filter( 'uni_wc_wishlist_table_image_size', 'uni_asana_theme_wishlist_table_image_size', 10, 1 );
function uni_asana_theme_wishlist_table_image_size( $sImageSize ) {
	return 'unithumb-cartimage';
}

//*********** Calendarius plugin support *************************************************
if ( function_exists( 'uni_ec_check_calendar_shortcode_added' ) ) :

//
function uni_asana_theme_ec_templates_builtin() {
	$bOutputTmpl = uni_ec_check_calendar_shortcode_added();
if ( $bOutputTmpl ) {
	?>
    <!-- Event Info modal template for built-in -->
    <script type="text/template" id="js-uni-calendar-info-event-tmpl">
        <div class="uni-ec-universal-container" style="border-color:<%= calEvent.borderColor %>;">
            <div class="uni-ec-bar uni-ec-title-bar <% if ( typeof chosenTheme !== 'undefined' && typeof UniCalendar.data.calThemes[chosenTheme] !== 'undefined' ) { print(UniCalendar.data.calThemes[chosenTheme]['class_name']); } else { print('uni-ec-theme-flat-cyan'); } %>"
                 style="background-color:<%= calEvent.backgroundColor %>;">
                <h3 style="color:<%= calEvent.textColor %>;"><%= calEvent.title %></h3>
            </div>

            <div class="uni-ec-form-content">

                <div class="uni-ec-form-section uni-ec-form-section-modal">

                    <% if ( calEvent.meta.event_all_day_enable && calEvent.meta.event_all_day_enable === 'yes' ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-duration">
                            <span class="uni-ec-info-section-duration-allday">
                                <i class="fa fa-clock-o" aria-hidden="true"></i>
	                            <?php esc_html_e( 'All day', 'uni-calendar' ) ?>
                            </span>
                    </div>
                    <% } else { %>
                    <div class="uni-ec-info-section uni-ec-info-section-availability">
                            <span class="uni-ec-info-section-duration-timed">
                                <i class="fa fa-clock-o" aria-hidden="true"></i>
                                <%= moment.utc(calEvent.start._i).format(uniTimeFormat) %>
                                &nbsp;&ndash;&nbsp;
                                <%= moment.utc(calEvent.end._i).format(uniTimeFormat) %>
                            </span>
                    </div>
                    <% } %>

                    <div class="uni-ec-info-section uni-ec-info-section-description uni-ec-form-section-nice-scroll">
                        <%= calEvent.meta.event_desc %>
                    </div>

                    <% if ( calEvent.meta.event_user ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-users">
                        <% _.each(calEvent.meta.event_user, function (value, key, list) {
                        if ( allUsers[value] ) {
                        %>
                        <span class="uni-ec-info-section-user-url">
                                <i class="fa fa-user" aria-hidden="true"></i>
                                <%= allUsers[value].name %>
                            </span>
                        <%
                        }
                        }); %>
                    </div>
                    <% } %>

                    <% if ( calEvent.meta.event_click_behavior && calEvent.meta.event_click_behavior == 'modal_uri' ) {
                    %>
                    <div class="uni-ec-info-section uni-ec-info-section-link">
                        <a class="uni-ec-info-section-link-url" href="<%= calEvent.meta.event_link_uri %>">
                            <%= calEvent.meta.event_link_text %>
                        </a>
                    </div>
                    <% } %>

                </div>

                <span class="js-uni-event-modal-close-btn uni-event-modal-close-btn"><?php esc_html_e( 'Close', 'uni-calendar' ) ?></span>

            </div>

        </div>
    </script>
<?php
}

/*global $post;
    if ( has_shortcode($post->post_content, 'uni-calendar') ) {
    ?>
    <!-- Event Info modal template for built-in -->
    <script type="text/template" id="js-uni-calendar-info-event-tmpl">
        <div class="uni-ec-universal-container">
            <div class="uni-ec-bar uni-ec-title-bar <% if ( typeof chosenTheme !== 'undefined' && typeof UniCalendar.data.calThemes[chosenTheme] !== 'undefined' ) { print(UniCalendar.data.calThemes[chosenTheme]['class_name']); } else { print('uni-ec-theme-flat-cyan'); } %>">
                <h3><%= calEvent.title %></h3>
            </div>

            <div class="uni-ec-form-content">

                <div class="uni-ec-form-section uni-ec-form-section-modal">

                    <% if ( calEvent.meta.event_all_day_enable && calEvent.meta.event_all_day_enable === 'yes' ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-duration">
                            <span class="uni-ec-info-section-duration-allday">
                                <i class="fa fa-clock-o" aria-hidden="true"></i>
                                <?php esc_html_e('All day', 'asana') ?>
                            </span>
                    </div>
                    <% } else { %>
                    <div class="uni-ec-info-section uni-ec-info-section-availability">
                            <span class="uni-ec-info-section-duration-timed">
                                <i class="fa fa-clock-o" aria-hidden="true"></i>
                                <%= moment.utc(calEvent.start._i).format(uniTimeFormat) %>
                                &nbsp;&ndash;&nbsp;
                                <%= moment.utc(calEvent.end._i).format(uniTimeFormat) %>
                            </span>
                    </div>
                    <% } %>

                    <div class="uni-ec-info-section uni-ec-info-section-description">
                        <%= calEvent.meta.event_desc %>
                    </div>

                    <% if ( calEvent.meta.event_user ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-users last">
                        <% _.each(calEvent.meta.event_user, function (value, key, list) {
                            if ( allUsers[value] ) {
                        %>
                            <span class="uni-ec-info-section-user-url">
                                <i class="fa fa-user" aria-hidden="true"></i>
                                <%= allUsers[value].name %>
                            </span>
                        <%
                            }
                        }); %>
                    </div>
                    <% } %>

                </div>

                <span class="js-uni-event-modal-close-btn uni-event-modal-close-btn"><?php esc_html_e('Close', 'asana') ?></span>

            </div>

        </div>
    </script>
    <?php
    }*/
}
remove_action( 'wp_footer', 'uni_ec_templates_builtin' );
add_action( 'wp_footer', 'uni_asana_theme_ec_templates_builtin' );

//
function uni_asana_theme_uni_ec_templates_mb() {
$bOutputTmpl = uni_ec_check_calendar_shortcode_added();
if ( $bOutputTmpl ) {
?>
    <!-- Event Info modal template for MindBodyOnine -->
    <script type="text/template" id="js-uni-calendar-info-event-mb-tmpl">
        <div class="uni-ec-universal-container" style="border-color:<%= calEvent.borderColor %>;">
            <div class="uni-ec-bar uni-ec-title-bar <% if ( typeof calEvent.meta.uni_input_cal_theme !== 'undefined' && typeof UniCalendar.data.calThemes[calEvent.meta.uni_input_cal_theme] !== 'undefined' ) { print(UniCalendar.data.calThemes[calEvent.meta.uni_input_cal_theme]['class_name']); } else { print('uni-ec-theme-flat-cyan'); } %>"
                 style="background-color:<%= calEvent.backgroundColor %>;">
                <h3 style="color:<%= calEvent.textColor %>;"><%= calEvent.title %></h3>
            </div>

            <div class="uni-ec-form-content">

                <div class="uni-ec-form-section uni-ec-form-section-modal">

                    <% if ( calEvent.meta.class_available === true ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-availability">
                            <span class="uni-ec-info-section-availability-active">
                                <i class="fa fa-calendar-check-o" aria-hidden="true"></i>
	                            <?php esc_html_e( 'Active', 'uni-calendar' ) ?>
                            </span>
                    </div>
                    <% } else { %>
                    <div class="uni-ec-info-section uni-ec-info-section-availability">
                            <span class="uni-ec-info-section-availability-cancelled">
                                <i class="fa fa-calendar-times-o" aria-hidden="true"></i>
	                            <?php esc_html_e( 'Cancelled', 'uni-calendar' ) ?>
                            </span>
                    </div>
                    <% } %>

                    <div class="uni-ec-info-section uni-ec-info-section-description uni-ec-form-section-nice-scroll">
                        <%= calEvent.meta.event_desc %>
                    </div>

                    <% if ( calEvent.meta.class_instructor ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-users last">
                            <span class="uni-ec-info-section-user-url">
                                <i class="fa fa-user" aria-hidden="true"></i>
                                <%= calEvent.meta.class_instructor %>
                            </span>
                    </div>
                    <% } %>

                </div>

                <span class="js-uni-event-modal-close-btn uni-event-modal-close-btn"><?php esc_html_e( 'Close', 'uni-calendar' ) ?></span>

            </div>

        </div>
    </script>
<?php
}
}
remove_action( 'wp_footer', 'uni_ec_templates_mb' );
add_action( 'wp_footer', 'uni_asana_theme_uni_ec_templates_mb' );

//
function uni_asana_theme_uni_ec_templates_cobot() {
$bOutputTmpl = uni_ec_check_calendar_shortcode_added();
if ( $bOutputTmpl ) {
?>
    <!-- Event Info modal template for Cobot.me -->
    <script type="text/template" id="js-uni-calendar-info-event-cobot-tmpl">
        <div class="uni-ec-universal-container" style="border-color:<%= calEvent.borderColor %>;">
            <div class="uni-ec-bar uni-ec-title-bar <% if ( typeof chosenTheme !== 'undefined' && typeof UniCalendar.data.calThemes[chosenTheme] !== 'undefined' ) { print(UniCalendar.data.calThemes[chosenTheme]['class_name']); } else { print('uni-ec-theme-flat-cyan'); } %>"
                 style="background-color:<%= calEvent.backgroundColor %>;">
                <h3 style="color:<%= calEvent.textColor %>;"><%= calEvent.title %></h3>
            </div>

            <div class="uni-ec-form-content">

                <div class="uni-ec-form-section uni-ec-form-section-modal">

                    <div class="uni-ec-info-section uni-ec-info-section-description uni-ec-form-section-nice-scroll">
                        <% if ( calEvent.meta.event_desc ) { %>
                        <%= calEvent.meta.event_desc %>
                        <% } else { %>
						<?php esc_html_e( 'No description.', 'uni-calendar' ) ?>
                        <% } %>
                    </div>

                </div>

                <span class="js-uni-event-modal-close-btn uni-event-modal-close-btn"><?php esc_html_e( 'Close', 'uni-calendar' ) ?></span>

            </div>

        </div>
    </script>
<?php
}
}
remove_action( 'wp_footer', 'uni_ec_templates_cobot' );
add_action( 'wp_footer', 'uni_asana_theme_uni_ec_templates_cobot' );

//
function uni_asana_theme_uni_ec_templates_tickera() {
$bOutputTmpl = uni_ec_check_calendar_shortcode_added();
if ( $bOutputTmpl ) {
?>
    <!-- Event Info modal template for Tickera events -->
    <script type="text/template" id="js-uni-calendar-info-event-tickera-tmpl">
        <div class="uni-ec-universal-container" style="border-color:<%= calEvent.borderColor %>;">
            <div class="uni-ec-bar uni-ec-title-bar <% if ( typeof chosenTheme !== 'undefined' && typeof UniCalendar.data.calThemes[chosenTheme] !== 'undefined' ) { print(UniCalendar.data.calThemes[chosenTheme]['class_name']); } else { print('uni-ec-theme-flat-cyan'); } %>"
                 style="background-color:<%= calEvent.backgroundColor %>;">
                <h3 style="color:<%= calEvent.textColor %>;"><%= calEvent.title %></h3>
            </div>

            <div class="uni-ec-form-content">

                <div class="uni-ec-form-section uni-ec-form-section-modal">

                    <% if ( calEvent.meta.event_location ) { %>
                    <div class="uni-ec-info-section uni-ec-info-section-location last">
                        <i class="fa fa-map-marker" aria-hidden="true"></i>
                        <%= calEvent.meta.event_location %>
                    </div>
                    <% } %>

                    <div class="uni-ec-info-section uni-ec-info-section-description uni-ec-form-section-nice-scroll">
                        <%= calEvent.meta.event_desc %>
                    </div>

                </div>

                <div class="uni-ec-form-section uni-ec-form-section-with-btn centered uni-ec-form-section-modal">
                    <a href="<%= calEvent.meta.event_page_uri %>" class="btn btn-inform"
                       target="_blank"><?php esc_html_e( 'The event page', 'uni-calendar' ) ?></a>
                    <button class="js-uni-event-modal-close-btn btn"
                            type="button"><?php esc_html_e( 'Close', 'uni-calendar' ) ?></button>
                </div>

            </div>

        </div>
    </script>
	<?php
}
}
	remove_action( 'wp_footer', 'uni_ec_templates_tickera' );
	add_action( 'wp_footer', 'uni_asana_theme_uni_ec_templates_tickera' );

endif;

//
header( "X-XSS-Protection: 0" );
?>